@@ -30,11 +30,14 @@ execute()
 	profile="$3"
 	file="$4"
 	pass="$6"
+
+	source "`dirname $0`/ffmpeg_utils.sh"
+
+	# generate filename if missing
 	[ "x$file" = "x" ] && file="kino_export_"`date +%Y-%m-%d_%H.%M.%S`
 
-	# Variable parameters
-	hq=""
-	[ $pass -eq "2" ] && hq="-deinterlace"
+	# only do high quality on second pass
+	[ $pass -eq "2" ] && ffmpeg_generate_hq
 
 	# Run the command
 	if [ "$profile" -ge "0" ] && [ "$profile" -le "1" ]; then 
