@@ -13,10 +13,10 @@ usage()
 	echo Flags: single-pass file-producer
 
 	# Profiles
-	echo "Profile: High Quality (640x480, VBR)"
+	echo "Profile: High Quality (640x480, VBR, QPEL)"
 	echo "Profile: Medium Quality (320x240, VBR)"
-	echo "Profile: Broadband Quality (320x240, 564 Kbps)"
-	echo "Profile: Low Quality (160x120, 12fps, 128 Kbps)"
+	echo "Profile: Broadband Quality (320x240, 564 kb/s)"
+	echo "Profile: Low Quality (160x120, 12fps, 128 kb/s)"
 }
 
 execute()
@@ -26,6 +26,11 @@ execute()
 	length="$2"
 	profile="$3"
 	file="$4"
+
+	source "`dirname $0`/ffmpeg_utils.sh"
+	ffmpeg_generate_hq
+
+	# generate filename if missing
 	[ "x$file" = "x" ] && file="kino_export_"`date +%Y-%m-%d_%H.%M.%S`
 	
 	# Determine audio codec (MP3 if avail)
@@ -36,15 +41,15 @@ execute()
 
 	# Run the command
 	case "$profile" in 
-		"0" ) 	ffmpeg -f dv -i pipe: -deinterlace -vtag DIVX -s 640x480 \
-			-aspect 4:3 -qscale 4 \
+		"0" ) 	ffmpeg -f dv -i pipe: $hq -vtag DIVX -s 640x480 \
+			-aspect 4:3 -qscale 2 $qpel \
 			-acodec "$acodec" -ab 192 -y "$file".avi ;;
-		"1" ) 	ffmpeg -f dv -i pipe: -deinterlace -vtag DIVX -s 320x240 \
+		"1" ) 	ffmpeg -f dv -i pipe: $hq -vtag DIVX -s 320x240 \
 			-aspect 4:3 -qscale 4 -acodec "$acodec" -ab 128 -y "$file".avi ;;
-		"2" ) 	ffmpeg -f dv -i pipe: -deinterlace -vtag DIVX -s 320x240 \
-			-aspect 4:3 -b 500 -acodec "$acodec" -ab 64 -y "$file".avi ;;
-		"3" ) 	ffmpeg -f dv -i pipe: -deinterlace -r 12 -g 36 -vtag DIVX -s 160x120 \
-			-aspect 4:3 -b 96 -acodec "$acodec" -ab 32 -y "$file".avi ;;
+		"2" ) 	ffmpeg -f dv -i pipe: $hq -vtag DIVX -s 320x240 \
+			-aspect 4:3 -b 500 -bt 5 -acodec "$acodec" -ab 64 -y "$file".avi ;;
+		"3" ) 	ffmpeg -f dv -i pipe: $hq -r 12 -g 36 -vtag DIVX -s 160x120 \
+			-aspect 4:3 -b 96 -bt 5 -acodec "$acodec" -ab 32 -y "$file".avi ;;
 	esac
 }
 
