@@ -44,8 +44,8 @@ execute()
 
 	# Determine info arguments
 	frame_rate=`[ "$normalisation" = "pal" ] && echo 25 || echo 29.97`
-	audio_format=`[ "$normalisation" = "pal" ] && echo mp2 || echo ac3`
-	audio_bitrate=`[ "$normalisation" = "pal" ] && echo 224 || echo 192`
+	audio_format="ac3"
+	audio_bitrate="192"
 
 	# Build path to extract_chapters Perl script
 	get_chapters="`dirname $0`/extract_chapters"
