@@ -59,7 +59,7 @@ execute()
 			-title "$title" -author "$author" -comment "$comment" -copyright "$copyright" \
 			-y "$file".mp4 ;;
 		"3" ) 	ffmpeg -f dv -i pipe: -pass $pass -passlogfile "$file" \
-			-$hq r 12 -g 36 -s 160x120 -aspect 4:3 -b 96 -ac 1 -ab 32 -ar 22050 $metadata \
+			$hq r 12 -g 36 -s 160x120 -aspect 4:3 -b 96 -ac 1 -ab 32 -ar 22050 $metadata \
 			-title "$title" -author "$author" -comment "$comment" -copyright "$copyright" \
 			-y "$file".mp4 ;;
 	esac
