@@ -42,6 +42,7 @@ using std::vector;
 class AudioFilter 
 {
 	public:
+		virtual ~AudioFilter() {}
 		virtual char *GetDescription( ) const = 0;
 		virtual void GetFrame( int16_t **buffer, int frequency, int channels, int& samples, double position, double frame_delta ) = 0;
 		virtual bool IsUsable( ) { return true; }
@@ -66,6 +67,7 @@ class AudioFilter
 class GDKAudioFilter : public AudioFilter
 {
 	public:
+		virtual ~GDKAudioFilter() {}
 		virtual void AttachWidgets( GtkBin *bin ) { }
 		virtual void InterpretWidgets( GtkBin *bin ) { }
 		virtual void DetachWidgets( GtkBin *bin ) { }
