@@ -148,11 +148,9 @@ private:
 	bool wav_selected;
 
 public:
-	WavSelect() : wav( NULL ), label_info( NULL ), file_entry( NULL ), wav_selected( false )
+	WavSelect() : wav( NULL ), label_info( NULL ), file_entry( NULL ), resampler(0), wav_selected( false )
 	{
 		strcpy( wav_file, "" );
-		resampler = AudioResampleFactory<int16_le_t,int16_ne_t>::createAudioResample(
-		                AUDIO_RESAMPLE_SRC_SINC_BEST_QUALITY );
 	}
 
 	~WavSelect()
@@ -210,7 +208,18 @@ public:
 	{
 		if ( wav_selected )
 		{
-			resampler->SetOutputFrequency( frequency );
+			if ( wav->GetFrequency() != frequency )
+			{
+				delete resampler;
+				resampler = AudioResampleFactory<int16_le_t,int16_ne_t>::createAudioResample(
+					AUDIO_RESAMPLE_SRC_SINC_BEST_QUALITY );
+				resampler->SetOutputFrequency( frequency );
+			}
+			else
+			{
+				delete resampler;
+				resampler = 0;
+			}
 			fps = frequency / samples;
 			wav->Seek( offset );
 		}
@@ -220,21 +229,33 @@ public:
 	{
 		if ( wav_selected )
 		{
-			memset( temp, 0, sizeof( temp ) );
-			int samples = bytes / c / 2 * wav->GetFrequency() / f;
-			bytes = samples * c * 2;
-			if ( !wav->Get( temp, bytes ) )
+			if ( resampler )
 			{
-				printf( ">>> Underrun? unable to read %d bytes\n", bytes );
+				memset( temp, 0, sizeof( temp ) );
+				int samples = bytes / c / 2 * wav->GetFrequency() / f;
+				bytes = samples * c * 2;
+				if ( !wav->Get( temp, bytes ) )
+					printf( ">>> Underrun? unable to read %d bytes\n", bytes );
+	
+				resampler->Resample( reinterpret_cast<int16_le_t *>(temp), wav->GetFrequency(), c, samples );
+	
+				int16_t *p = resampler->output;
+				for ( int s = 0; s < resampler->size / c / 2; s ++ )
+					for ( int i = 0; i < c; i ++ )
+						a[ i ][ s ] = *p++;
+				return (resampler->size / c / 2);
+			}
+			else
+			{
+				memset( temp, 0, sizeof( temp ) );
+				if ( !wav->Get( temp, bytes ) )
+					printf( ">>> Underrun? unable to read %d bytes\n", bytes );
+				int16_t *p = temp;
+				for ( int s = 0; s < bytes / c / 2; s ++ )
+					for ( int i = 0; i < c; i ++ )
+						a[ i ][ s ] = *p++;
+				return (bytes / c / 2);
 			}
-
-			resampler->Resample( reinterpret_cast<int16_le_t *>(temp), wav->GetFrequency(), c, samples );
-
-			int16_t *p = resampler->output;
-			for ( int s = 0; s < resampler->size / c / 2; s ++ )
-				for ( int i = 0; i < c; i ++ )
-					a[ i ][ s ] = *p++;
-			return resampler->size / c / 2;
 		}
 		return 0;
 	}
@@ -304,7 +325,7 @@ public:
 		}
 
 		if ( initiated )
-			WavRead( aframe, frequency, channels, samples * channels * 2 );
+			samples = WavRead( aframe, frequency, channels, samples * channels * 2 );
 	}
 
 	static void
@@ -404,8 +425,8 @@ public:
 		}
 		if ( initiated )
 		{
-			int samplesRead = WavRead( bframe, frequency, channels, samples * channels * 2 );
-			Mix( aframe, bframe, channels, samplesRead );
+			samples = WavRead( bframe, frequency, channels, samples * channels * 2 );
+			Mix( aframe, bframe, channels, samples );
 		}
 	}
 
