@@ -15,72 +15,6 @@
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
-*
-* Tag: $Name:  $
-*
-* Change log:
-* 
-* $Log: avi.h,v $
-* Revision 1.15  2004/10/11 01:37:11  ddennedy
-* mutex safety locks in RIFF and AVI classes, type 2 AVI optimization, mencoder export script
-*
-* Revision 1.14  2003/11/25 23:00:52  ddennedy
-* cleanup and a few bugfixes
-*
-* Revision 1.13  2003/10/21 16:34:32  ddennedy
-* GNOME2 port phase 1: initial checkin
-*
-* Revision 1.11.2.5  2003/07/24 14:13:57  ddennedy
-* support for distinct audio stream in type2 AVI and Quicktime; support for more DV FOURCCs
-*
-* Revision 1.11.2.4  2003/06/10 23:53:36  ddennedy
-* Daniel Kobras' WriteFrame error handling and automatic OpenDML, bugfixes in scene list updates, export AV/C Record
-*
-* Revision 1.11.2.3  2003/02/20 21:59:57  ddennedy
-* bugfixes to capture and AVI
-*
-* Revision 1.11.2.2  2003/01/13 05:15:31  ddennedy
-* added More Info panel and supporting methods
-*
-* Revision 1.11.2.1  2002/11/25 04:48:31  ddennedy
-* bugfix to report errors when loading files
-*
-* Revision 1.11  2002/10/08 07:46:41  ddennedy
-* AVI bugfixes, compatibility, optimization, warn bad file in capture and export dv file, allow no mplex
-*
-* Revision 1.10  2002/05/17 08:04:25  ddennedy
-* revert const-ness of Frame references in Frame, FileHandler, and AVI classes
-*
-* Revision 1.9  2002/05/15 04:39:35  ddennedy
-* bugfixes to dv2 AVI write, audio export, Xv init
-*
-* Revision 1.8  2002/04/29 05:09:22  ddennedy
-* raw dv file support, Frame::ExtractAudio uses libdv, audioScrub prefs
-*
-* Revision 1.7  2002/04/09 06:53:42  ddennedy
-* cleanup, new libdv 0.9.5, large AVI, dnd storyboard
-*
-* Revision 1.7  2002/03/25 21:34:25  arne
-* Support for large (64 bit) files mostly completed
-*
-* Revision 1.6  2002/03/10 13:29:41  arne
-* more changes for 64 bit access
-*
-* Revision 1.5  2002/03/09 17:59:28  arne
-* moved index routines to AVIFile
-*
-* Revision 1.4  2002/03/09 10:26:26  arne
-* improved constructors and assignment operator
-*
-* Revision 1.3  2002/03/09 08:55:57  arne
-* moved a few variables to AVIFile
-*
-* Revision 1.2  2002/03/04 19:22:43  arne
-* updated to latest Kino avi code
-*
-* Revision 1.1.1.1  2002/03/03 19:08:08  arne
-* import of version 1.01
-*
 */
 
 /** Common AVI declarations
@@ -97,10 +31,12 @@
 #include "riff.h"
 #include "frame.h"
 
+#define PACKED(x)	__attribute__((packed)) x
+
 #define AVI_SMALL_INDEX (0x01)
 #define AVI_LARGE_INDEX (0x02)
-#define AVI_INDEX_OF_INDEXES (0x00)
-#define AVI_INDEX_OF_CHUNKS (0x01)
+#define KINO_AVI_INDEX_OF_INDEXES (0x00)
+#define KINO_AVI_INDEX_OF_CHUNKS (0x01)
 #define AVI_INDEX_2FIELD (0x01)
 
 enum { AVI_PAL, AVI_NTSC, AVI_AUDIO_48KHZ, AVI_AUDIO_44KHZ, AVI_AUDIO_32KHZ };
@@ -134,13 +70,13 @@ typedef struct
 
 	DWORD dwReserved[ 4 ];
 }
-MainAVIHeader;
+PACKED(MainAVIHeader);
 
 typedef struct
 {
 	WORD top, bottom, left, right;
 }
-RECT;
+PACKED(RECT);
 
 /** Declaration of a stream header
  
@@ -163,7 +99,7 @@ typedef struct
 	DWORD dwSampleSize;
 	RECT rcFrame;
 }
-AVIStreamHeader;
+PACKED(AVIStreamHeader);
 
 typedef struct
 {
@@ -175,7 +111,7 @@ typedef struct
 	DWORD dwDVVAuxCtl;
 	DWORD dwDVReserved[ 2 ];
 }
-DVINFO;
+PACKED(DVINFO);
 
 typedef struct
 {
@@ -191,7 +127,7 @@ typedef struct
 	DWORD biClrUsed;
 	DWORD biClrImportant;
 }
-BITMAPINFOHEADER;
+PACKED(BITMAPINFOHEADER);
 
 typedef struct
 {
@@ -204,7 +140,7 @@ typedef struct
 	WORD cbSize;
 	WORD dummy;
 }
-WAVEFORMATEX;
+PACKED(WAVEFORMATEX);
 
 typedef struct
 {
@@ -212,7 +148,7 @@ typedef struct
 	BYTE bIndexSubType;
 	BYTE bIndexType;
 	DWORD nEntriesInUse;
-	DWORD dwChunkId;
+	FOURCC dwChunkId;
 	DWORD dwReserved[ 3 ];
 	struct avisuperindex_entry
 	{
@@ -222,7 +158,7 @@ typedef struct
 	}
 	aIndex[ 2014 ];
 }
-AVISuperIndex;
+PACKED(AVISuperIndex);
 
 typedef struct
 {
@@ -230,7 +166,7 @@ typedef struct
 	BYTE bIndexSubType;
 	BYTE bIndexType;
 	DWORD nEntriesInUse;
-	DWORD dwChunkId;
+	FOURCC dwChunkId;
 	QUADWORD qwBaseOffset;
 	DWORD dwReserved;
 	struct avifieldindex_entry
@@ -238,9 +174,9 @@ typedef struct
 		DWORD dwOffset;
 		DWORD dwSize;
 	}
-	aIndex[ 4028 ];
+	aIndex[ 17895 ];
 }
-AVIStdIndex;
+PACKED(AVIStdIndex);
 
 typedef struct
 {
@@ -254,7 +190,7 @@ typedef struct
 	aIndex[ 20000 ];
 	DWORD	nEntriesInUse;
 }
-AVISimpleIndex;
+PACKED(AVISimpleIndex);
 
 typedef struct
 {
@@ -333,7 +269,7 @@ protected:
 	int index_type;
 	int current_ix00;
 
-	int dmlh[ 62 ];
+	DWORD dmlh[ 62 ];
 	int odml_list;
 	int dmlh_chunk;
 	bool isUpdateIdx1;
