@@ -531,14 +531,6 @@ on_menuitem_trim_activate ( GtkMenuItem *menuitem,
 
 
 
-void
-on_save_as_eli1_activate ( GtkMenuItem *menuitem,
-                           gpointer user_data )
-{
-	savePlayListAsEli( );
-}
-
-
 void
 on_fx1_activate ( GtkMenuItem *menuitem,
                   gpointer user_data )
@@ -672,7 +664,7 @@ on_entry_focus_out_event               (GtkWidget       *widget,
                                         GdkEventFocus   *event,
                                         gpointer         user_data)
 {
-	g_nav_ctl.escaped = TRUE;
+	g_nav_ctl.escaped = FALSE;
 	return FALSE;
 }
 
