@@ -1,4 +1,13 @@
-#include <gnome.h>
+#ifndef _CALLBACKS_H
+#define _CALLBACKS_H
+
+#include <glib/gi18n.h>
+#include <gtk/gtk.h>
+
+#ifdef __cplusplus
+extern "C"
+{
+#endif
 
 #include "preferences_dialog.h"
 
@@ -80,12 +89,6 @@ on_main_notebook_switch_page ( GtkNotebook *notebook,
                                gint page_num,
                                gpointer user_data );
 
-void
-on_iconlist1_select_icon ( GnomeIconList *gnomeiconlist,
-                           gint arg1,
-                           GdkEvent *event,
-                           gpointer user_data );
-
 void
 on_timeline_ok_button_pressed ( GtkButton *button,
                                 gpointer user_data );
@@ -279,12 +282,6 @@ on_capture_page_file_entry_button_press_event ( GtkWidget *widget,
         GdkEventButton *event,
         gpointer user_data );
 
-void
-on_capture_page_gnome_file_entry_browse_clicked
-( GnomeFileEntry *gnomefileentry,
-  gpointer user_data );
-
-
 void
 on_notebook_export_switch_page ( GtkNotebook *notebook,
                                  GtkNotebookPage *page,
@@ -520,11 +517,6 @@ on_eventbox6_visibility_notify_event ( GtkWidget *widget,
                                        GdkEvent *event,
                                        gpointer user_data );
 
-void
-on_fileentry_magick_dub_file_browse_clicked
-( GnomeFileEntry *gnomefileentry,
-  gpointer user_data );
-
 void
 on_entry17_changed ( GtkEditable *editable,
                      gpointer user_data );
@@ -616,11 +608,6 @@ void
 on_command_reference_activate ( GtkMenuItem *menuitem,
                                 gpointer user_data );
 
-void
-on_button_more_info_clicked ( GtkButton *button,
-                              gpointer user_data );
-
-
 gboolean
 on_preferences_dialog_destroy_event ( GtkWidget *widget,
                                       GdkEvent *event,
@@ -657,22 +644,6 @@ void
 on_time_format_none_activate ( GtkMenuItem *menuitem,
                                gpointer user_data );
 
-void
-on_button_more_info_clicked ( GtkButton *button,
-                              gpointer user_data );
-
-void
-on_position_label_current_size_allocate
-( GtkWidget *widget,
-  GdkRectangle *allocation,
-  gpointer user_data );
-
-void
-on_position_label_total_size_allocate ( GtkWidget *widget,
-                                        GdkRectangle *allocation,
-                                        gpointer user_data );
-
-
 void
 on_spinbutton_trim_in_value_changed ( GtkSpinButton *spinbutton,
                                       gpointer user_data );
@@ -919,3 +890,18 @@ void
 on_preferences_dialog_help_button_clicked
                                         (GtkButton       *button,
                                         gpointer         user_data);
+
+void
+on_iconview_timeline_item_activated    (GtkIconView     *iconview,
+                                        GtkTreePath     *path,
+                                        gpointer         user_data);
+
+void
+on_expander_properties_activate        (GtkExpander     *expander,
+                                        gpointer         user_data);
+
+#ifdef __cplusplus
+}
+#endif
+
+#endif
