@@ -19,9 +19,16 @@ enum
    DESC_COLUMN,
    N_COLUMNS
 };
+
+GtkWidget* tree = lookup_widget( dialog, "list_keyhelp_edit" );
+GList *columns = gtk_tree_view_get_columns( GTK_TREE_VIEW( tree ) );
+gint count = g_list_length( columns );
+g_list_free( columns );
+
+if ( count == 0 )
+{
 	GtkListStore *store;
 	GtkTreeIter   iter;
-	GtkWidget* tree;
 	GtkCellRenderer* renderer;
 	GtkTreeViewColumn *column;
 	
@@ -63,16 +70,16 @@ enum
 	CMD_COLUMN, _("[n] k, -, <up-arrow>"),
 	DESC_COLUMN, _("Move to start of previous scene"), -1 );
  gtk_list_store_append( store, &iter );  gtk_list_store_set( store, &iter,
-	CMD_COLUMN, _("gg"),
+	CMD_COLUMN, _("gg, Home"),
 	DESC_COLUMN, _("Move to first frame"), -1 );
  gtk_list_store_append( store, &iter );  gtk_list_store_set( store, &iter,
-	CMD_COLUMN, _("G"),
+	CMD_COLUMN, _("G, End"),
 	DESC_COLUMN, _("Move to last frame"), -1 );
  gtk_list_store_append( store, &iter );  gtk_list_store_set( store, &iter,
-	CMD_COLUMN, _("Ctrl+F"),
+	CMD_COLUMN, _("Ctrl+F, Page Down"),
 	DESC_COLUMN, _("Move forward 5 scenes"), -1 );
  gtk_list_store_append( store, &iter );  gtk_list_store_set( store, &iter,
-	CMD_COLUMN, _("Ctrl+B"),
+	CMD_COLUMN, _("Ctrl+B, Page Up"),
 	DESC_COLUMN, _("Move backward 5 scenes"), -1 );
  gtk_list_store_append( store, &iter );  gtk_list_store_set( store, &iter,
 	CMD_COLUMN, _("Cut"),
@@ -151,7 +158,7 @@ enum
 	DESC_COLUMN, _("Split scene before current frame"), -1 );
  gtk_list_store_append( store, &iter );  gtk_list_store_set( store, &iter,
 	CMD_COLUMN, _("[n] J"),
-	DESC_COLUMN, "Join this scene with the following scene", -1 );
+	DESC_COLUMN, _("Join this scene with the following scene"), -1 );
  gtk_list_store_append( store, &iter );  gtk_list_store_set( store, &iter,
 	CMD_COLUMN, _("u, Ctrl+Z"),
 	DESC_COLUMN, _("Undo"), -1 );
@@ -160,7 +167,7 @@ enum
 	DESC_COLUMN, _("Redo"), -1 );
  gtk_list_store_append( store, &iter );  gtk_list_store_set( store, &iter,
 	CMD_COLUMN, _("Ctrl+O"),
-	DESC_COLUMN, "File/Open", -1 );
+	DESC_COLUMN, _("File/Open"), -1 );
  gtk_list_store_append( store, &iter );  gtk_list_store_set( store, &iter,
 	CMD_COLUMN, _("Ctrl+P"),
 	DESC_COLUMN, _("Preferences"), -1 );
@@ -173,9 +180,6 @@ enum
  gtk_list_store_append( store, &iter );  gtk_list_store_set( store, &iter,
 	CMD_COLUMN, _(":A"),
 	DESC_COLUMN, _("Append file (DV AVI or SMIL) to movie"), -1 );
- gtk_list_store_append( store, &iter );  gtk_list_store_set( store, &iter,
-	CMD_COLUMN, _(":W"),
-	DESC_COLUMN, _("Switch to export mode"), -1 );
  gtk_list_store_append( store, &iter );  gtk_list_store_set( store, &iter,
 	CMD_COLUMN, _(":w, Ctrl+S"),
 	DESC_COLUMN, _("Save the movie as SMIL"), -1 );
@@ -186,7 +190,6 @@ enum
 	CMD_COLUMN, _(":<numeric>"),
 	DESC_COLUMN, _("Move to specified frame"), -1 );
 
-	tree = lookup_widget( dialog, "list_keyhelp_edit" );
 	gtk_tree_view_set_model( GTK_TREE_VIEW( tree ), GTK_TREE_MODEL( store ) );
 	g_object_unref( G_OBJECT( store ) );
 	renderer = gtk_cell_renderer_text_new();
@@ -235,10 +238,10 @@ enum
 	CMD_COLUMN, _("k, -, <up-arrow>"),
 	DESC_COLUMN, _("Previous Index"), -1 );
  gtk_list_store_append( store, &iter );  gtk_list_store_set( store, &iter,
-	CMD_COLUMN, _("gg"),
+	CMD_COLUMN, _("gg, Home"),
 	DESC_COLUMN, _("Rewind"), -1 );
  gtk_list_store_append( store, &iter );  gtk_list_store_set( store, &iter,
-	CMD_COLUMN, _("G"),
+	CMD_COLUMN, _("G, End"),
 	DESC_COLUMN, _("Fast Forward"), -1 );
  gtk_list_store_append( store, &iter );  gtk_list_store_set( store, &iter,
 	CMD_COLUMN, _("Mode Switching"),
@@ -248,10 +251,10 @@ enum
 	DESC_COLUMN, _("Return to Edit"), -1 );
  gtk_list_store_append( store, &iter );  gtk_list_store_set( store, &iter,
 	CMD_COLUMN, _("t, F4"),
-	DESC_COLUMN, _("Switch to Trim"), -1 );
+	DESC_COLUMN, _("Switch to Timeline"), -1 );
  gtk_list_store_append( store, &iter );  gtk_list_store_set( store, &iter,
 	CMD_COLUMN, _("v, F5"),
-	DESC_COLUMN, _("Switch to Timeline"), -1 );
+	DESC_COLUMN, _("Switch to Trim"), -1 );
  gtk_list_store_append( store, &iter );  gtk_list_store_set( store, &iter,
 	CMD_COLUMN, _("C, F6"),
 	DESC_COLUMN, _("Switch to FX"), -1 );
@@ -274,8 +277,11 @@ enum
 	CMD_COLUMN, _("Ctrl+P"),
 	DESC_COLUMN, _("Preferences"), -1 );
  gtk_list_store_append( store, &iter );  gtk_list_store_set( store, &iter,
-	CMD_COLUMN, _("."),
-	DESC_COLUMN, _("Repeat last command"), -1 );
+	CMD_COLUMN, _(":w, Ctrl+S"),
+	DESC_COLUMN, _("Save the movie as SMIL"), -1 );
+ gtk_list_store_append( store, &iter );  gtk_list_store_set( store, &iter,
+	CMD_COLUMN, _(":q, Ctrl+Q"),
+	DESC_COLUMN, _("Quit"), -1 );
 
 	tree = lookup_widget( dialog, "list_keyhelp_capture" );
 	gtk_tree_view_set_model( GTK_TREE_VIEW( tree ), GTK_TREE_MODEL( store ) );
@@ -329,10 +335,10 @@ enum
 	CMD_COLUMN, _("k, -, <up-arrow>"),
 	DESC_COLUMN, _("Move to start of previous scene"), -1 );
  gtk_list_store_append( store, &iter );  gtk_list_store_set( store, &iter,
-	CMD_COLUMN, _("gg"),
+	CMD_COLUMN, _("gg, Home"),
 	DESC_COLUMN, _("Move to first frame"), -1 );
  gtk_list_store_append( store, &iter );  gtk_list_store_set( store, &iter,
-	CMD_COLUMN, _("G"),
+	CMD_COLUMN, _("G, End"),
 	DESC_COLUMN, _("Move to last frame"), -1 );
  gtk_list_store_append( store, &iter );  gtk_list_store_set( store, &iter,
 	CMD_COLUMN, _("Trimming"),
@@ -408,7 +414,7 @@ enum
 	DESC_COLUMN, _("Split scene before current frame"), -1 );
  gtk_list_store_append( store, &iter );  gtk_list_store_set( store, &iter,
 	CMD_COLUMN, _("[n] J"),
-	DESC_COLUMN, "Join this scene with the following scene", -1 );
+	DESC_COLUMN, _("Join this scene with the following scene"), -1 );
  gtk_list_store_append( store, &iter );  gtk_list_store_set( store, &iter,
 	CMD_COLUMN, _("u, Ctrl+Z"),
 	DESC_COLUMN, _("Undo edits"), -1 );
@@ -434,10 +440,7 @@ enum
 	CMD_COLUMN, _(":A"),
 	DESC_COLUMN, _("Append file (DV AVI or SMIL) to movie"), -1 );
  gtk_list_store_append( store, &iter );  gtk_list_store_set( store, &iter,
-	CMD_COLUMN, _(":W"),
-	DESC_COLUMN, _("Switch to export mode"), -1 );
- gtk_list_store_append( store, &iter );  gtk_list_store_set( store, &iter,
-	CMD_COLUMN, _(":w, crtrl-s"),
+	CMD_COLUMN, _(":w, Ctrl+S"),
 	DESC_COLUMN, _("Save the movie as SMIL"), -1 );
  gtk_list_store_append( store, &iter );  gtk_list_store_set( store, &iter,
 	CMD_COLUMN, _(":q, Ctrl+Q"),
@@ -456,3 +459,54 @@ enum
 	renderer = gtk_cell_renderer_text_new();
 	column = gtk_tree_view_column_new_with_attributes( _("Description"), renderer, "text", DESC_COLUMN, NULL );
 	gtk_tree_view_append_column( GTK_TREE_VIEW( tree ), column );
+	
+	store = gtk_list_store_new( N_COLUMNS, G_TYPE_STRING, G_TYPE_STRING );
+ gtk_list_store_append( store, &iter );  gtk_list_store_set( store, &iter,
+	CMD_COLUMN, _("Mode Switching"),
+	DESC_COLUMN, "-------------------------------------", -1 );
+ gtk_list_store_append( store, &iter );  gtk_list_store_set( store, &iter,
+	CMD_COLUMN, _("Esc, F2"),
+	DESC_COLUMN, _("Return to Edit"), -1 );
+ gtk_list_store_append( store, &iter );  gtk_list_store_set( store, &iter,
+	CMD_COLUMN, _("a, A, F3"),
+	DESC_COLUMN, _("Switch to Capture"), -1 );
+ gtk_list_store_append( store, &iter );  gtk_list_store_set( store, &iter,
+	CMD_COLUMN, _("v, F4"),
+	DESC_COLUMN, _("Switch to Timeline"), -1 );
+ gtk_list_store_append( store, &iter );  gtk_list_store_set( store, &iter,
+	CMD_COLUMN, _("v, F5"),
+	DESC_COLUMN, _("Switch to Trim"), -1 );
+ gtk_list_store_append( store, &iter );  gtk_list_store_set( store, &iter,
+	CMD_COLUMN, _("C, F6"),
+	DESC_COLUMN, _("Switch to FX"), -1 );
+ gtk_list_store_append( store, &iter );  gtk_list_store_set( store, &iter,
+	CMD_COLUMN, _(":W, F7"),
+	DESC_COLUMN, _("Switch to Export"), -1 );
+ gtk_list_store_append( store, &iter );  gtk_list_store_set( store, &iter,
+	CMD_COLUMN, _("General"),
+	DESC_COLUMN, "-------------------------------------", -1 );
+ gtk_list_store_append( store, &iter );  gtk_list_store_set( store, &iter,
+	CMD_COLUMN, _("Ctrl+O"),
+	DESC_COLUMN, _("File/Open"), -1 );
+ gtk_list_store_append( store, &iter );  gtk_list_store_set( store, &iter,
+	CMD_COLUMN, _("Ctrl+P"),
+	DESC_COLUMN, _("Preferences"), -1 );
+ gtk_list_store_append( store, &iter );  gtk_list_store_set( store, &iter,
+	CMD_COLUMN, _(":w, Ctrl+S"),
+	DESC_COLUMN, _("Save the movie as SMIL"), -1 );
+ gtk_list_store_append( store, &iter );  gtk_list_store_set( store, &iter,
+	CMD_COLUMN, _(":q, Ctrl+Q"),
+	DESC_COLUMN, _("Quit"), -1 );
+	
+	tree = lookup_widget( dialog, "list_keyhelp_other" );
+	gtk_tree_view_set_model( GTK_TREE_VIEW( tree ), GTK_TREE_MODEL( store ) );
+	g_object_unref( G_OBJECT( store ) );
+	renderer = gtk_cell_renderer_text_new();
+	column = gtk_tree_view_column_new_with_attributes( _("Command"), renderer, "text", CMD_COLUMN, NULL );
+	gtk_tree_view_column_set_resizable( column, TRUE );
+	gtk_tree_view_append_column( GTK_TREE_VIEW( tree ), column );
+	renderer = gtk_cell_renderer_text_new();
+	column = gtk_tree_view_column_new_with_attributes( _("Description"), renderer, "text", DESC_COLUMN, NULL );
+	gtk_tree_view_append_column( GTK_TREE_VIEW( tree ), column );
+	
+}
