@@ -733,7 +733,7 @@ Displayer *FindDisplayer::getDisplayer( GtkWidget *drawingarea, int width, int h
 	switch ( prefs.displayMode )
 	{
 	case DISPLAY_XV:
-		display = new XvDisplayer( drawingarea, width, height, true, false );
+		display = new XvDisplayer( drawingarea, width, height, (height > 480), false );
 		if ( !display->usable() )
 		{
 			delete display;
@@ -743,7 +743,7 @@ Displayer *FindDisplayer::getDisplayer( GtkWidget *drawingarea, int width, int h
 	case DISPLAY_XX:
 		if ( display == NULL )
 		{
-			display = new XvDisplayer( drawingarea, width / 2, height / 2, true, false );
+			display = new XvDisplayer( drawingarea, width / 2, height / 2, (height > 480), false );
 			if ( !display->usable() )
 			{
 				delete display;
