@@ -212,12 +212,11 @@ bool FileHandler::Done()
 
 bool FileHandler::WriteFrame( const Frame& frame )
 {
-	static TimeCode prevTimeCode;
+	static TimeCode prevTimeCode = { 0, 0, -1, 0 };
 	TimeCode timeCode;
 
 	/* If the user wants autosplit, start a new file if a
 	   new recording is detected. */
-	prevTimeCode.sec = -1;
 	frame.GetTimeCode( timeCode );
 	int time_diff = timeCode.sec - prevTimeCode.sec;
 	bool discontinuity = prevTimeCode.sec != -1 && ( time_diff > 1 || ( time_diff < 0 && time_diff > -59 ) );
