@@ -87,7 +87,7 @@ Frame::Frame() : bytesInFrame( 0 ), tempImage( 0 )
 {
 #if defined(HAVE_LIBAVCODEC)
 	pthread_mutex_lock( &avcodec_mutex );
-	avcodec_init();
+	av_register_all();
 	libavcodec = avcodec_alloc_context();
 	libavcodec->thread_count = 2;
 	avcodec_open( libavcodec, &dvvideo_decoder );
@@ -1328,20 +1328,47 @@ void Frame::EncodeRGB( uint8_t *rgb )
 #if defined(HAVE_LIBAVCODEC)
 		AVFrame *input = avcodec_alloc_frame();
 		AVFrame *output = avcodec_alloc_frame();
+
 		if ( input && output )
 		{
 			int width = avcodecEncoder->width;
 			int height = avcodecEncoder->height;
 			size_t size = height > 480 ? 144000 : 120000;
 
+			// Convert color space
 			avpicture_fill( ( AVPicture* )output, tempImage, avcodecEncoder->pix_fmt, width, height );
 			avpicture_fill( ( AVPicture* )input, rgb, PIX_FMT_RGB24, width, height );
-
 			img_convert( ( AVPicture* )output, avcodecEncoder->pix_fmt, ( AVPicture* )input, PIX_FMT_RGB24, width, height );
 
+			// Encode
 			bytesInFrame = avcodec_encode_video( avcodecEncoder, data, size, output );
+
+			// Use libavformat to mux the DV  because libavcodec produces an incomplete DIF bytstream
+			AVFormatContext *oc = av_alloc_format_context();
+			oc->oformat = guess_format( "dv", NULL, NULL );
+			AVStream *video_st = av_new_stream(oc, 0);
+			AVPacket pkt;
+			uint8_t* buf = new uint8_t[ bytesInFrame ];
+		
+			av_set_parameters(oc, NULL);
+			url_open_buf( &oc->pb, buf, bytesInFrame, URL_WRONLY );
+			video_st->codec = avcodecEncoder;
+			av_write_header(oc);
+			av_init_packet(&pkt);
+			pkt.stream_index = video_st->index;
+			pkt.data = data;
+			pkt.size = bytesInFrame;
+			av_write_frame(oc, &pkt);
+			url_close_buf(&oc->pb);
+			memcpy(data, buf, bytesInFrame);
+			av_write_trailer(oc);
+
+			// Update this frame's metadata
 			ExtractHeader();
 
+			delete[] buf;
+			av_freep(&video_st);
+			av_free(oc);
 			av_free( output );
 			av_free( input );
 		}
