@@ -46,15 +46,9 @@ FrameDisplayer::FrameDisplayer() :
 
 FrameDisplayer::~FrameDisplayer()
 {
-	if ( displayer != NULL )
-		delete displayer;
-
-	if ( resampler != NULL )
-		delete resampler;
-
+	delete displayer;
 	for ( gint i = 0; i < 4; i++ )
 		free( audio_buffers[ i ] );
-	
 	CloseSound();
 }
 
@@ -66,6 +60,8 @@ void FrameDisplayer::CloseSound()
 		kino_sound_close( audio_device );
 		audio_device_avail = FALSE;
 		audio_device = NULL;
+		delete resampler;
+		resampler = NULL;
 	}
 }
 
@@ -79,9 +75,11 @@ void FrameDisplayer::PutSound( Frame &frame )
 			audio_device = kino_sound_new();
 		if ( audio_device != NULL )
 		{
-			if ( !audio_device_avail &&
+			if ( !audio_device_avail && 
 					( audio_sampling_rate = kino_sound_init( frame.decoder->audio, audio_device, prefs.audioDevice ) ) != 0 )
+			{
 				audio_device_avail = TRUE;
+			}
 			if ( audio_device_avail )
 			{
 				if ( resampler == NULL )
