@@ -76,7 +76,7 @@ struct _GtkEnhancedScaleClass
 
 GtkWidget* gtk_enhanced_scale_new ( GtkObject * adjustment[],
 									gint num_adjustments );
-guint gtk_enhanced_scale_get_type ( void );
+GType gtk_enhanced_scale_get_type ( void );
 void gtk_enhanced_scale_set_breaks( GtkWidget * widget, GArray * breaks );
 
 #ifdef __cplusplus
