@@ -319,12 +319,12 @@ public:
 	ImageCreateGradiate()
 	{
 		window = glade_xml_get_widget( magick_glade, "image_create_gradiate" );
-		start_right.red = start_right.green = start_right.blue = 1 << 16;
+		start_right.red = start_right.green = start_right.blue = 0;
 		GtkWidget* widget = lookup_widget( window, "colorpicker_start_right" );
 		gtk_color_button_set_color( GTK_COLOR_BUTTON( widget ), &start_right );
 		g_signal_connect( G_OBJECT( widget ), "color-set", G_CALLBACK( Repaint ), 0 );
 
-		end_right.red = end_right.green = end_right.blue = 1 << 16;
+		end_right.red = end_right.green = end_right.blue = 0;
 		widget = lookup_widget( window, "colorpicker_end_right" );
 		gtk_color_button_set_color( GTK_COLOR_BUTTON( widget ), &end_right );
 		g_signal_connect( G_OBJECT( widget ), "color-set", G_CALLBACK( Repaint ), 0 );
