@@ -43,6 +43,7 @@ using std::vector;
 class ImageCreate 
 {
 	public:
+		virtual ~ImageCreate() {}
 		virtual char *GetDescription( ) const = 0;
 		virtual void CreatePAL( bool is_pal ) { }
 		virtual void CreateFrame( uint8_t *pixels, int width, int height, double position, double frame_delta ) = 0;
@@ -69,6 +70,7 @@ class ImageCreate
 class GDKImageCreate : public ImageCreate
 {
 	public:
+		virtual ~GDKImageCreate() {}
 		virtual void AttachWidgets( GtkBin *bin ) { }
 		virtual void DetachWidgets( GtkBin *bin ) { }
 		virtual void InterpretWidgets( GtkBin *bin ) { }
@@ -90,6 +92,7 @@ class GDKImageCreate : public ImageCreate
 class GDKAudioImport : public GDKImageCreate
 {
 	public:
+		virtual ~GDKAudioImport() {}
 		virtual void CreateAudio( int16_t **buffer, short int *channels, int *frequency, int *samples ) = 0;
 };
 
