@@ -26,6 +26,7 @@
 #include "image_filters.h"
 #include "error.h"
 #include "page_magick.h"
+#include "kino_extra.h"
 
 // C Includes
 
@@ -124,6 +125,8 @@ public:
 	ImageFilterMirror()
 	{
 		window = glade_xml_get_widget( magick_glade, "image_filter_mirror" );
+		GtkWidget* widget = glade_xml_get_widget( magick_glade, "optionmenu_mirror" );
+		g_signal_connect( G_OBJECT( widget ), "changed", G_CALLBACK( Repaint ), 0 );
 	}
 
 	virtual ~ImageFilterMirror()
@@ -131,6 +134,11 @@ public:
 		gtk_widget_destroy( window );
 	}
 
+	static void Repaint( void )
+	{
+		GetSelectedFramesForFX().Repaint();
+	}
+
 	char *GetDescription( ) const
 	{
 		return _( "Mirror" );
@@ -233,6 +241,8 @@ public:
 	ImageFilterKaleidoscope()
 	{
 		window = glade_xml_get_widget( magick_glade, "image_filter_kaleidoscope" );
+		GtkWidget* widget = glade_xml_get_widget( magick_glade, "optionmenu_kaleidoscope" );
+		g_signal_connect( G_OBJECT( widget ), "changed", G_CALLBACK( Repaint ), 0 );
 	}
 
 	virtual ~ImageFilterKaleidoscope()
@@ -240,6 +250,11 @@ public:
 		gtk_widget_destroy( window );
 	}
 
+	static void Repaint( void )
+	{
+		GetSelectedFramesForFX().Repaint();
+	}
+
 	char *GetDescription( ) const
 	{
 		return _( "Kaleidoscope" );
@@ -427,6 +442,8 @@ public:
 	ImageFilterSwap()
 	{
 		window = glade_xml_get_widget( magick_glade, "image_filter_swap" );
+		GtkWidget* widget = glade_xml_get_widget( magick_glade, "optionmenu_swap" );
+		g_signal_connect( G_OBJECT( widget ), "changed", G_CALLBACK( Repaint ), 0 );
 	}
 
 	virtual ~ImageFilterSwap()
@@ -434,6 +451,11 @@ public:
 		gtk_widget_destroy( window );
 	}
 
+	static void Repaint( void )
+	{
+		GetSelectedFramesForFX().Repaint();
+	}
+
 	char *GetDescription( ) const
 	{
 		return _( "Swap" );
