@@ -107,6 +107,11 @@ static DATAChunk DATAChunk_Init( )
 
 static void WAVStruct_WriteHeader( WAVStruct wav )
 {
+	if ( wav->isapipe )
+	{
+		wav->riff->length |= 0x7ffff000;
+		wav->data->length |= 0x7ffff000;
+	}
 	fwrite( wav->riff, sizeof( RIFFChunkType ), 1, wav->file );
 	fwrite( wav->format, sizeof( FORMATChunkType ), 1, wav->file );
 	fwrite( wav->data, sizeof( DATAChunkType ), 1, wav->file );
