@@ -278,10 +278,7 @@ void KinoCommon::fetchProjectMetadata( const std::string& projectKey )
 	}
 	else if ( httpContext )
 	{
-		char msg[1024];
-		snprintf( msg, 1024, "Server responded with error %d", code );
-		//cerr << "Error: " << msg << endl;
-		modal_message( msg );
+		modal_message( "Server responded with error %d", code );
 	}
 	if ( httpContext )
 		xmlNanoHTTPClose( httpContext );
@@ -299,6 +296,7 @@ bool KinoCommon::newFile( bool prompt )
 
 	cerr << ">> Kino Common newFile" << endl;
 
+	this->getPageMagick()->Stop();
 	this->changePageRequest( PAGE_EDITOR );
 	if ( getPlayList() ->IsDirty() )
 	{
@@ -559,7 +557,7 @@ std::string KinoCommon::importFile( const char *filename )
 	std::string importedFile( filename );
 
 	if ( modal_confirm( GTK_STOCK_OK, NULL,
-		_("This is not a DV file. Do you want to import it?") )
+		_("\"%s\" is not a DV file. Do you want to import it?"), filename )
 		== GTK_RESPONSE_ACCEPT )
 	{
 		char * args[ 7 ];
@@ -587,8 +585,19 @@ std::string KinoCommon::importFile( const char *filename )
 			// Use Preferences/Defaults
 			if ( Preferences::getInstance().defaultNormalisation == NORM_UNSPECIFIED )
 			{
-				modal_message( _( "The playlist is empty and the default preferences for video creation have not been specified - aborting." ) );
-				return importedFile;
+				switch ( modal_confirm( "PAL", "NTSC", _("Please choose a video standard") ) )
+				{
+				case GTK_RESPONSE_ACCEPT:
+					Preferences::getInstance().defaultNormalisation = NORM_PAL;
+					break;
+				case GTK_RESPONSE_CLOSE:
+					Preferences::getInstance().defaultNormalisation = NORM_NTSC;
+					break;
+				default:
+					// Do nothing - action cancelled
+					gtk_widget_hide( dialog );
+					return importedFile;
+				}
 			}
 			args[ 3 ] = const_cast<char*>(
 				Preferences::getInstance().defaultNormalisation == NORM_PAL ? "pal" : "ntsc" );
@@ -687,7 +696,7 @@ void KinoCommon::insertFile( )
 			}
 			else
 			{
-				modal_message( _( "Failed to load media file." ) );
+				modal_message( _( "Failed to load media file \"%s\"" ), importedFile.c_str() );
 			}
 			break;
 		}
@@ -740,7 +749,7 @@ void KinoCommon::appendFile( )
 			}
 			else
 			{
-				modal_message( _( "Failed to load media file." ) );
+				modal_message( _( "Failed to load media file \"%s\"" ), importedFile.c_str() );
 			}
 			break;
 		}
@@ -790,6 +799,8 @@ void KinoCommon::loadFile( )
 				}
 				// Else, ask to import
 			}
+			else
+				break;
 		case UNKNOWN_FORMAT:
 			if ( ( askNewFile && newFile( ) ) || ! askNewFile )
 			{
@@ -802,7 +813,7 @@ void KinoCommon::loadFile( )
 				}
 				else
 				{
-					modal_message( _( "Failed to load media file." ) );
+					modal_message( _( "Failed to load media file \"%s\"" ), importedFile.c_str() );
 				}
 			}
 			break;
@@ -837,8 +848,9 @@ void KinoCommon::loadFile( )
 bool KinoCommon::savePlayListAs( )
 {
 	bool result = false;
-	//changePageRequest( PAGE_EDITOR );
-	char *filename = this->getFileToSave( _( "Save the movie as SMIL" ) );
+	int format = 1;
+	char *filename = this->getFileToSaveFormat( _( "Save the movie as SMIL" ), format );
+
 	if ( filename && strcmp( filename, "" ) )
 	{
 		// See if it exists already and warn user
@@ -849,35 +861,42 @@ bool KinoCommon::savePlayListAs( )
 			if ( modal_confirm( GTK_STOCK_SAVE, NULL, _("The file \"%s\" already exists. Do you want to continue?\n"), filename ) != GTK_RESPONSE_ACCEPT )
 				return result;
 		}
-		playlist.SetDocName( filename );
-		result = savePlayList( filename );
+		switch ( format )
+		{
+			case 0: // SMIL
+				playlist.SetDocName( filename );
+				result = savePlayList( filename );
+				break;
+			case 1: // Legacy XML
+				if ( !this->getPlayList()->SavePlayList( filename, true ) )
+				{
+					modal_message( _( "Could not save the XML" ) );
+					result = false;
+				}
+				break;
+			case 2: // ELI
+				if ( g_currentFrame != -1 )
+				{
+					Frame& frame = *GetFramePool()->GetFrame();
+					this->getPlayList() ->GetFrame( g_currentFrame, frame );
+					if ( !this->getPlayList() ->SavePlayListEli( filename, frame.IsPAL() ) )
+					{
+						modal_message( _( "Could not save the ELI" ) );
+						result = false;
+					}
+					GetFramePool()->DoneWithFrame( &frame );
+				}
+				else
+				{
+					modal_message( _( "Could not save the ELI" ) );
+					result = false;
+				}
+				break;
+		}
 	}
 	return result;
 }
 
-/** Save the current play list with a different name to the original loaded (or
-       previously saved as) play list file name in Eli format
-*/
-
-void KinoCommon::savePlayListAsEli( )
-{
-	if ( g_currentFrame == -1 )
-		return ;
-
-	Frame& frame = *GetFramePool()->GetFrame();
-
-	this->getPlayList() ->GetFrame( g_currentFrame, frame );
-	changePageRequest( PAGE_EDITOR );
-	char *filename = this->getFileToSave( _( "Save the movie as ELI" ) );
-	if ( filename && strcmp( filename, "" ) )
-	{
-		if ( this->getPlayList() ->SavePlayListEli( filename,
-		        frame.IsPAL() ) == false )
-			modal_message( _( "Could not save the ELI" ) );
-	}
-	GetFramePool()->DoneWithFrame( &frame );
-}
-
 /** Save the current play list to the file used to load the playlist originally. If
 	no file was originally used then use savePlayListAs to obtain one.
 */
@@ -918,7 +937,7 @@ Used by update_preview_cb to generate a file preview in the File->Open dialog
 */
 gboolean generate_file_preview( GtkWidget *preview, const char *filename )
 {
-	FileHandler *mediaFile = NULL;
+	FileHandler *mediaFile = 0;
 	try
 	{
 		if ( strcmp( filename, "" ) )
@@ -945,17 +964,20 @@ gboolean generate_file_preview( GtkWidget *preview, const char *filename )
 			// causing nothing to show
 			Frame& frame = *GetFramePool()->GetFrame();
 			int frameNum = mediaFile->GetTotalFrames() < 61 ? ( mediaFile->GetTotalFrames() / 2 ) : 60;
-			unsigned char *pixels = new unsigned char[ FRAME_MAX_WIDTH * FRAME_MAX_HEIGHT * 4 ];
-
-			mediaFile->GetFrame( frame, frameNum );
-			GdkDisplayer* display = new GdkDisplayer( preview, frame.GetWidth(), frame.GetHeight(), frame.IsWide() );
-			frame.ExtractPreviewRGB( pixels );
-			display->put( pixels );
 
+			if ( mediaFile->GetFrame( frame, frameNum ) >= 0 )
+			{
+				GdkDisplayer* display = new GdkDisplayer( preview, frame.GetWidth(), frame.GetHeight(), frame.IsWide() );
+				unsigned char *pixels = new unsigned char[ FRAME_MAX_WIDTH * FRAME_MAX_HEIGHT * 4 ];
+				frame.ExtractPreviewRGB( pixels );
+				display->put( pixels );
+				delete[] pixels;
+				delete display;
+			}
 			GetFramePool()->DoneWithFrame( &frame );
-			delete display;
-			delete[] pixels;
 			delete mediaFile;
+			mediaFile = 0;
+
 			return true;
 		}
 	}
@@ -964,6 +986,7 @@ gboolean generate_file_preview( GtkWidget *preview, const char *filename )
 		cerr << "generate_file_preview exception: " << s << endl;
 	}
 	delete mediaFile;
+
 	return false;
 }
 
@@ -1008,7 +1031,8 @@ char *KinoCommon::getFileToOpen( char *title, bool isDVFile, GtkWidget *widget )
 				GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
 				GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT,
 				static_cast<gchar*>( NULL ) );
-	gtk_dialog_set_alternative_button_order (GTK_DIALOG (dialog), GTK_RESPONSE_ACCEPT, GTK_RESPONSE_CANCEL, -1);
+	gtk_dialog_set_alternative_button_order( GTK_DIALOG(dialog), GTK_RESPONSE_ACCEPT, GTK_RESPONSE_CANCEL, -1 );
+// 	gtk_file_chooser_set_select_multiple( GTK_FILE_CHOOSER(dialog), TRUE );
 
 	if ( isDVFile )
 	{
@@ -1079,9 +1103,10 @@ char *KinoCommon::getFileToOpen( char *title, bool isDVFile, GtkWidget *widget )
 	return tempFileName;
 }
 
-char *KinoCommon::getFileToSave( char *title, GtkWidget *widget )
+char *KinoCommon::getFileToSaveFormat( char *title, GtkWidget *widget, int& format )
 {
 	GtkWidget *dialog;
+	GtkComboBox* formatCombo = NULL;
 
 	dialog = gtk_file_chooser_dialog_new( title,
 					getWidgetWindow(widget),
@@ -1091,6 +1116,26 @@ char *KinoCommon::getFileToSave( char *title, GtkWidget *widget )
 					static_cast<gchar*>( NULL ) );
 	gtk_dialog_set_alternative_button_order (GTK_DIALOG (dialog), GTK_RESPONSE_ACCEPT, GTK_RESPONSE_CANCEL, -1);
 	gtk_window_set_modal( GTK_WINDOW( dialog ), TRUE );
+
+	if ( format )
+	{
+		GtkWidget* hbox = gtk_hbox_new( FALSE, 6 );
+		GtkWidget* label = gtk_label_new_with_mnemonic( _("F_ormat:") );
+		
+		formatCombo = GTK_COMBO_BOX( gtk_combo_box_new_text() );
+		gtk_widget_show( hbox );
+		gtk_widget_show( label );
+		gtk_widget_show( GTK_WIDGET( formatCombo ) );
+	
+		gtk_combo_box_append_text( formatCombo, "SMIL 2.0" );
+		gtk_combo_box_append_text( formatCombo, "Kino < 0.9.1 XML" );
+		gtk_combo_box_append_text( formatCombo, "MJPEG Tools ELI" );
+		gtk_combo_box_set_active( formatCombo, 0 );
+		gtk_box_pack_start( GTK_BOX(hbox), label, FALSE, FALSE, 0 );
+		gtk_box_pack_start( GTK_BOX(hbox), GTK_WIDGET(formatCombo), FALSE, FALSE, 0 );
+		gtk_file_chooser_set_extra_widget( GTK_FILE_CHOOSER( dialog ), hbox );
+	}
+
 	if ( last_directory == "" )
 	{
 		string directory = getPlayList() ->GetProjectDirectory( );
@@ -1113,6 +1158,8 @@ char *KinoCommon::getFileToSave( char *title, GtkWidget *widget )
 			strcpy( tempFileName, "" );
 	} else
 		strcpy(tempFileName, "");
+	if ( format )
+		format = gtk_combo_box_get_active( GTK_COMBO_BOX(formatCombo) );
 
 	gtk_widget_destroy (dialog);
 	return tempFileName;
@@ -1157,7 +1204,7 @@ char *KinoCommon::getFileToOpen( char *title, bool isDVFile )
 	return tempFileName;
 }
 
-char *KinoCommon::getFileToSave( char *title)
+char *KinoCommon::getFileToSave( char *title )
 {
 	return getFileToOpen(title);
 }
@@ -1309,7 +1356,7 @@ bool KinoCommon::loadPlayList( char *file, int before )
 			this->getPlayList()->SetDocTitle( newList.GetDocTitle().c_str() );
 	}
 	else
-		modal_message( _( "Could not load the SMIL" ) );
+		modal_message( _( "Could not load the SMIL file \"%s\"" ), file );
 
 	return result;
 }
