@@ -5,18 +5,10 @@ on_eventbox_magick_event ( GtkWidget *widget,
                            GdkEvent *event,
                            gpointer user_data );
 
-void
-on_togglebutton_magick_preview_toggled ( GtkToggleButton *togglebutton,
-        gpointer user_data );
-
 void
 on_togglebutton_magick_start_toggled ( GtkToggleButton *togglebutton,
                                        gpointer user_data );
 
-void
-on_togglebutton_magick_stop_toggled ( GtkToggleButton *togglebutton,
-                                      gpointer user_data );
-
 void
 on_optionmenu_magick_filter_clicked ( GtkButton *button,
                                       gpointer user_data );
