@@ -24,12 +24,12 @@ extern "C"
 {
 #endif
 
-void modal_message ( const char * message );
-char *modal_prompt( const char * message );
+void modal_message ( const char * message, ... );
+char *modal_prompt( const char * message, ... );
 int modal_confirm( const char * affirm_label, const char *close_label, const char *message, ... );
 	
-void modal_message_with_parent ( const char * message, GtkWidget *parent );
-char *modal_prompt_with_parent( const char * message, GtkWidget *parent );
+void modal_message_with_parent ( GtkWidget *parent, const char * message, ... );
+char *modal_prompt_with_parent( GtkWidget *parent, const char * message, ... );
 int modal_confirm_with_parent( const char * affirm_label, const char *close_label, GtkWidget *parent, const char *message, ... );
 
 #ifdef __cplusplus
