@@ -292,7 +292,12 @@ void PageCapture::applyAVCState( quadlet_t newAVCState )
 			validComponents = 0;
 			common->activateWidgets( );
 			common->commitComponentState();
+#ifdef HAVE_IEC61883
 			common->setStatusBar( _( "WARNING: raw1394 kernel module not loaded or failure to read/write /dev/raw1394!" ) );
+#else
+			common->setStatusBar( _( "WARNING: dv1394 kernel module not loaded or failure to read/write %s" ),
+				Preferences::getInstance().dvCaptureDevice );
+#endif
 		}
 		gui_state_was = 0;
 	}
