@@ -47,12 +47,7 @@ Export1394::Export1394( PageExport *_exportPage, KinoCommon *_common ) :
 		system_loaded( false )
 {
 	cerr << "> Creating Export1394 Page" << endl;
-
-	entry_cip_n = GTK_ENTRY( lookup_widget( common->getWidget(), "entry_export_1394_cip_n" ) );
-	entry_cip_d = GTK_ENTRY( lookup_widget( common->getWidget(), "entry_export_1394_cip_d" ) );
-	entry_syt_offset = GTK_ENTRY( lookup_widget( common->getWidget(), "entry_export_1394_syt_offset" ) );
 	entry_preroll = GTK_ENTRY( lookup_widget( common->getWidget(), "spinbutton_export_1394_preroll" ) );
-	feedbackLabel = GTK_LABEL( lookup_widget( common->getWidget(), "label_export_1394_load_messages" ) );
 }
 
 /** Destructor for page.
@@ -69,52 +64,51 @@ Export1394::~Export1394()
 void Export1394::start()
 {
 	static raw1394handle_t handle;
-	GtkLabel * load_label
-	= GTK_LABEL( lookup_widget ( exportPage->getWidget(),
-	                             "label_export_1394_load_messages" ) );
-
 	gchar s[ 512 ];
 
 	cerr << ">> Starting Export1394" << endl;
 
-	sprintf( s, "%d", Preferences::getInstance().cip_n );
-	gtk_entry_set_text( entry_cip_n, s );
-	sprintf( s, "%d", Preferences::getInstance().cip_d );
-	gtk_entry_set_text( entry_cip_d, s );
-	sprintf( s, "%d", Preferences::getInstance().syt_offset );
-	gtk_entry_set_text( entry_syt_offset, s );
 	sprintf( s, "%d", Preferences::getInstance().dvExportPrerollSec );
 	gtk_entry_set_text( entry_preroll, s );
 
-#ifdef LIBRAW1394_OLD
-
-	if ( ( handle = raw1394_get_handle() ) )
-	{
-#else
 	if ( ( handle = raw1394_new_handle() ) )
 	{
-#endif
 		if ( raw1394_set_port( handle, 0 ) >= 0 )
 		{
 			raw1394_destroy_handle( handle );
 			handle = NULL;
-			avc = new AVC( Preferences::getInstance().interface );
-			system_loaded = true;
-			gtk_label_set_text( load_label, "" );
+			avc = new AVC();
+			Preferences::getInstance( ).phyID = avc->getNodeId( Preferences::getInstance( ).avcGUID );
+			Preferences::getInstance( ).phyID = avc->isPhyIDValid( Preferences::getInstance( ).phyID );
+			system_loaded = Preferences::getInstance( ).phyID >= 0;
+			if ( !system_loaded )
+			{
+				common->setStatusBar( _( "No AV/C compliant cam connected or not switched on?" ) );
+				delete avc;
+				avc = 0;
+			}
 		}
 		else
 		{
 			system_loaded = false;
-			gtk_label_set_text( load_label,
-			                    _( "Error setting the IEEE 1394 port (host adapater); all IEEE 1394 options are disabled." ) );
+			common->setStatusBar( _( "Error setting the IEEE 1394 port (host adapater)." ) );
 		}
 	}
+#ifdef HAVE_IEC61883
 	else
 	{
 		system_loaded = false;
-		gtk_label_set_text( load_label,
-		                    _( "The IEEE 1394 subsystem is not loaded; all IEEE 1394 options are disabled." ) );
+		common->setStatusBar( _( "The IEEE 1394 subsystem is not loaded; all IEEE 1394 options are disabled." ) );
 	}
+#else
+	else
+	{
+		system_loaded = false;
+		common->setStatusBar( _( "Failed to open raw1394; you must manually control recording on the device." ) );
+	}
+#endif
+
+#ifdef HAVE_IEC61883
 	/* Change the sensitivity of the hosting widget according to
 	   wheter the system loaded or not */
 	GtkVBox * tmp
@@ -128,6 +122,23 @@ void Export1394::start()
 	{
 		gtk_widget_set_sensitive ( GTK_WIDGET ( tmp ), FALSE );
 	}
+#endif
+
+#ifdef HAVE_IEC61883
+	if ( avc )
+		exportWriter = new iec61883Writer( avc->getPort(),
+					   Preferences::getInstance().channel,
+					   Preferences::getInstance().dvExportBuffers );
+#else
+	exportWriter = new dv1394Writer(
+					   Preferences::getInstance().dvExportDevice,
+					   Preferences::getInstance().channel,
+					   Preferences::getInstance().dvExportBuffers,
+					   Preferences::getInstance().cip_n,
+					   Preferences::getInstance().cip_d,
+					   Preferences::getInstance().syt_offset
+				   );
+#endif
 
 }
 
@@ -142,10 +153,15 @@ gulong Export1394::onActivate()
 	{
 		return EXPORT_PREVIEW | EXPORT_EXPORT | EXPORT_SCENE_LIST;
 	}
+#ifdef HAVE_IEC61883
+	else
+		return 0;
+#else
 	else
 	{
-		return 0;
+		return EXPORT_PREVIEW | EXPORT_SCENE_LIST;
 	}
+#endif
 }
 
 /** Leaving the page
@@ -154,12 +170,10 @@ gulong Export1394::onActivate()
 void Export1394::clean()
 {
 	cerr << ">> Leaving Export1394" << endl;
-	if ( avc )
-	{
-		delete avc;
-		avc = NULL;
-	}
-	Preferences::getInstance().Save();
+	delete exportWriter;
+	exportWriter = NULL;
+	delete avc;
+	avc = NULL;
 }
 
 /** The actual export function */
@@ -169,27 +183,14 @@ Export1394::doExport( PlayList * playlist, int begin, int end, int every,
                       bool preview )
 {
 	int i = -1;
-	Preferences::getInstance().cip_n = atoi( gtk_entry_get_text( entry_cip_n ) );
-	Preferences::getInstance().cip_d = atoi( gtk_entry_get_text( entry_cip_d ) );
-	Preferences::getInstance().syt_offset = atoi( gtk_entry_get_text( entry_syt_offset ) );
 	Preferences::getInstance().dvExportPrerollSec = atoi( gtk_entry_get_text( entry_preroll ) );
 	enum export_result result = EXPORT_RESULT_FAILURE;
 	string filename = "";
 	string currentFilename = "";
 
-	exportWriter = new dv1394Writer(
-					   Preferences::getInstance().dvExportDevice,
-					   Preferences::getInstance().channel,
-					   Preferences::getInstance().dvExportBuffers,
-					   Preferences::getInstance().cip_n,
-					   Preferences::getInstance().cip_d,
-					   Preferences::getInstance().syt_offset
-				   );
-
 	// Only for export, NOT for preview.
-	if ( !preview )
+	if ( !preview && avc )
 	{
-		Preferences::getInstance().phyID = avc->getNodeId( Preferences::getInstance().avcGUID );
 		avc->Record( Preferences::getInstance().phyID );
 	}
 
@@ -203,13 +204,25 @@ Export1394::doExport( PlayList * playlist, int begin, int end, int every,
 
 		int16_t *audio_buffers[ 4 ];
 		AudioInfo info;
-		AudioResample<int16_ne_t,int16_ne_t> *resampler = NULL;
+		AsyncAudioResample<int16_ne_t,int16_le_t>* resampler = 0;
+		double adjustedRate;
+		int frameNum = 0;
 
 		for ( i = 0; i < 4; i++ )
 			audio_buffers[ i ] = ( int16_t * ) calloc( 2 * DV_AUDIO_MAX_SAMPLES, sizeof( int16_t ) );
 
-		/* pre-roll */
+		// Calculate resample rate for locked audio
 		playlist->GetFrame( begin, frame );
+		if ( resample )
+		{
+			// first call to innerLoopUpdate initializes progress tracker, which
+			// we want to do because calculateAdjustedRate generates paused time.
+			innerLoopUpdate( begin, begin, end, every );
+			frame.GetAudioInfo( info );
+			adjustedRate = calculateAdjustedRate( playlist, info.frequency, i, end, every );
+		}
+
+		/* pre-roll */
 		for ( i = begin; i <= end && i <= begin +
 		        Preferences::getInstance().dvExportPrerollSec * ( frame.IsPAL() ? 25 : 30 )
 		        && exportPage->isExporting; i++ )
@@ -223,7 +236,7 @@ Export1394::doExport( PlayList * playlist, int begin, int end, int every,
 		}
 
 		/* Iterate over all frames in selection */
-		for ( i = begin; i <= end && exportPage->isExporting; i += every )
+		for ( i = begin; i <= end && exportPage->isExporting; i += every, frameNum++ )
 		{
 			/* Call innerLoopUpdate */
 			innerLoopUpdate( i, begin, end, every );
@@ -233,28 +246,41 @@ Export1394::doExport( PlayList * playlist, int begin, int end, int every,
 			if ( currentFilename != filename )
 			{
 				filename = currentFilename;
-				gtk_label_set_text( feedbackLabel, filename.c_str() );
+				common->setStatusBar( filename.c_str() );
 			}
 
-			/* Get the frame, write it */
 			playlist->GetFrame( i, frame );
 
 			/* resample audio */
 			if ( resample )
 			{
-				if ( resampler == NULL )
+				if ( ! resampler && adjustedRate )
 				{
 					frame.GetAudioInfo( info );
-					resampler = AudioResampleFactory<int16_ne_t,int16_ne_t>::createAudioResample(
-					                AUDIO_RESAMPLE_SRC_SINC_MEDIUM_QUALITY, info.frequency );
+
+					// Determine correct amount of audio for duration
+					resampler = new AsyncAudioResample<int16_ne_t,int16_le_t>(
+						AUDIO_RESAMPLE_SRC_SINC_MEDIUM_QUALITY, playlist, info.frequency, i, end, every );
+					if ( ! resampler )
+					{
+						result = EXPORT_RESULT_FAILURE;
+						break;
+					}
+					if ( resampler->IsError() )
+					{
+						result = EXPORT_RESULT_FAILURE;
+						std::cerr << ">>> Resampler error: " << resampler->GetError() << std::endl;
+						break;
+					}
 				}
-				resampler->Resample( frame );
-				info.samples = resampler->size / info.channels / 2;
-				int16_t *p = resampler->output;
+				int requestedSamples = frame.CalculateNumberSamples( info.frequency, frameNum );
+				info.samples = resampler->Process( adjustedRate, requestedSamples );
+				int16_t *p = reinterpret_cast<int16_t *>( resampler->GetOutput() );
 				for ( int s = 0; s < info.samples; s++ )
 					for ( int c = 0; c < info.channels; c++ )
 						audio_buffers[ c ][ s ] = *p++;
-				frame.EncodeAudio( info, audio_buffers );
+				if ( info.samples )
+					frame.EncodeAudio( info, audio_buffers );
 			}
 
 			exportWriter->SendFrame( frame );
@@ -267,20 +293,16 @@ Export1394::doExport( PlayList * playlist, int begin, int end, int every,
 			
 		for ( i = 0; i < 4; i++ )
 			free( audio_buffers[ i ] );
-		if ( resampler != NULL )
-			delete resampler;
+		delete resampler;
 			
 		GetFramePool()->DoneWithFrame( &frame );
 	}
 
-	gtk_label_set_text( feedbackLabel, "" );
-	if ( !preview )
+	common->setStatusBar( "" );
+	if ( !preview && avc )
 	{
 		avc->Stop( Preferences::getInstance().phyID );
 	}
 
-	delete exportWriter;
-	exportWriter = NULL;
-
 	return result;
 }
