@@ -217,19 +217,18 @@ ExportAVI::doExport( PlayList * playlist, int begin, int end, int every,
 		                    lookup_widget( common->getWidget(), "checkbutton_export_avi_resample" ) ) );
 		int16_t *audio_buffers[ 4 ];
 		AudioInfo info;
-		AudioResample<int16_ne_t,int16_le_t> *resampler = NULL;
+		AsyncAudioResample<int16_ne_t,int16_le_t>* resampler = 0;
+		double adjustedRate = 0;
 
 		for ( i = 0; i < 4; i++ )
 			audio_buffers[ i ] = ( int16_t * ) calloc( 2 * DV_AUDIO_MAX_SAMPLES, sizeof( int16_t ) );
 
 		/* Iterate over all frames */
-		for ( i = begin; i <= end && exportPage->isExporting; i += every )
+		for ( i = begin; i <= end && exportPage->isExporting; i += every, frameNum++ )
 		{
-
-			/* Call innerLoopUpdate */
 			innerLoopUpdate( i, begin, end, every );
 
-			/* Extract frame, write stuff */
+			// Check for split
 			playlist->GetFrame( i, frame );
 			if ( Preferences::getInstance().autoSplit && writer->FileIsOpen()
 			        && ( i > 0 ) && ( i == scene[ sceneIndex ] ) )
@@ -237,6 +236,8 @@ ExportAVI::doExport( PlayList * playlist, int begin, int end, int every,
 				sceneIndex++;
 				writer->Close();
 				frameNum = 0;
+				delete resampler;
+				resampler = 0;
 			}
 
 /* Always resample on big-endian machines to perform endianness conversion. */
@@ -245,25 +246,48 @@ ExportAVI::doExport( PlayList * playlist, int begin, int end, int every,
 			if ( resample )
 #endif
 			{
-				if ( resampler == NULL )
+				if ( ! resampler )
 				{
 					frame.GetAudioInfo( info );
-					resampler = AudioResampleFactory<int16_ne_t,int16_le_t>::createAudioResample(
-					                AUDIO_RESAMPLE_SRC_SINC_BEST_QUALITY, info.frequency );
+
+					// Determine correct amount of audio for duration
+					adjustedRate = calculateAdjustedRate( playlist, info.frequency, i,
+						Preferences::getInstance().autoSplit ? ( scene[ sceneIndex ] - 1 ) : end, every );
+					if ( ! adjustedRate )
+					{
+						status = EXPORT_RESULT_ABORT;
+						break;
+					}
+
+					// Setup a resampler
+					resampler = new AsyncAudioResample<int16_ne_t,int16_le_t>(
+						AUDIO_RESAMPLE_SRC_SINC_BEST_QUALITY, playlist, info.frequency, i,
+						Preferences::getInstance().autoSplit ? ( scene[ sceneIndex ] - 1 ) : end, every );
+					if ( ! resampler )
+					{
+						status = EXPORT_RESULT_FAILURE;
+						break;
+					}
+					if ( resampler->IsError() )
+					{
+						status = EXPORT_RESULT_FAILURE;
+						throw string( _("Resampler Error: ") ) + resampler->GetError();
+					}
 				}
-				resampler->Resample( frame );
-				info.samples = resampler->size / info.channels / 2;
-				int16_t *p = reinterpret_cast<int16_t *>(resampler->output);
+				int requestedSamples = frame.CalculateNumberSamples( info.frequency, frameNum );
+				info.samples = resampler->Process( adjustedRate, requestedSamples );
+				int16_t *p = reinterpret_cast<int16_t *>( resampler->GetOutput() );
 				for ( int s = 0; s < info.samples; s++ )
 					for ( int c = 0; c < info.channels; c++ )
 						audio_buffers[ c ][ s ] = *p++;
-				frame.EncodeAudio( info, audio_buffers );
+				if ( info.samples )
+					frame.EncodeAudio( info, audio_buffers );
 			}
 
 			if ( updateMetadata )
 			{
 				frame.SetRecordingDate( &datetime, i );
-				frame.SetTimeCode( frameNum++ );
+				frame.SetTimeCode( frameNum );
 			}
 			if ( writer->WriteFrame( frame ) == false )
 				throw _( "Failed to write to file. Is file name OK?" );
@@ -274,9 +298,8 @@ ExportAVI::doExport( PlayList * playlist, int begin, int end, int every,
 
 		for ( i = 0; i < 4; i++ )
 			free( audio_buffers[ i ] );
-		if ( resampler != NULL )
-			delete resampler;
-
+		delete resampler;
+		resampler = 0;
 	}
 	catch ( string s )
 	{
