@@ -172,6 +172,7 @@ ExportMJPEG::ExportMJPEG( PageExport *_exportPage, KinoCommon *_common ) :
 	mjpegAspect
 	= GTK_MENU( gtk_option_menu_get_menu( GTK_OPTION_MENU( lookup_widget( exportPage->getWidget(),
 	                                      "optionmenu_export_aspect_ratio" ) ) ) );
+
 	cerr << "> Initializing MJPEG Export Page settings from Preferences" << endl;
 	gtk_option_menu_set_history( GTK_OPTION_MENU( lookup_widget( exportPage->getWidget(),
 								"optionmenu_export_mjpeg_format" ) ), prefs.exportMjpegFormat );
@@ -182,6 +183,9 @@ ExportMJPEG::ExportMJPEG( PageExport *_exportPage, KinoCommon *_common ) :
 	gtk_toggle_button_set_active( splitCheck, prefs.exportMjpegSceneSplit );
 	gtk_toggle_button_set_active( cleanupCheck, prefs.exportMjpegCleanup );
 	gtk_toggle_button_set_active( authorCheck , prefs.exportMjpegOutputDVDAuthorXML );
+	gtk_entry_set_text( mjpegVideo, prefs.exportMjpegVideoPipe );
+	gtk_entry_set_text( mjpegAudio, prefs.exportMjpegAudioPipe );
+	gtk_entry_set_text( mjpegMultiplexer, prefs.exportMjpegMultiplex );
 
 	if ( system( "yuvdeinterlace -h 2> /dev/null" ) == 0 )
 	{
@@ -291,10 +295,13 @@ ExportMJPEG::doExport( PlayList * playlist, int begin, int end, int every,
 	bool isY4Minterlaced = true;
 
 	videopipeInput = gtk_entry_get_text( mjpegVideo );
+	strncpy( prefs.exportMjpegVideoPipe, videopipeInput, sizeof(prefs.exportMjpegVideoPipe) );
 	GtkWidget *active_item = gtk_menu_get_active( mjpegFormat );
 	videoformat = g_list_index ( GTK_MENU_SHELL ( mjpegFormat ) ->children, active_item );
 	audioencode = gtk_entry_get_text( mjpegAudio );
+	strncpy( prefs.exportMjpegAudioPipe, audioencode, sizeof(prefs.exportMjpegAudioPipe) );
 	multiplexer = gtk_entry_get_text( mjpegMultiplexer );
+	strncpy( prefs.exportMjpegMultiplex, multiplexer, sizeof(prefs.exportMjpegMultiplex) );
 	active_item = gtk_menu_get_active( deinterlaceMenu );
 	deinterlaceRequest = g_list_index ( GTK_MENU_SHELL ( deinterlaceMenu ) ->children, active_item );
 	split = gtk_toggle_button_get_active( splitCheck );
@@ -362,9 +369,20 @@ ExportMJPEG::doExport( PlayList * playlist, int begin, int end, int every,
 		case 6:
 			videoformat = 8;
 			strcpy( scale, "" );
-			frequency = 48000;
-			if ( !strstr( audioencode, " -b " ) )
-				sprintf( audioOptions, "%s -b 192", audioOptions );
+			if ( strstr( audioencode, "ffmpeg" ) )
+			{
+				frequency = 48000;
+				if ( !strstr( audioencode, " -ab " ) )
+					sprintf( audioOptions, "%s -ab 192", audioOptions );
+			}
+			else if ( strstr( audioencode, "mp2enc" ) )
+			{
+				if ( !strstr( audioencode, " -r " ) )
+					sprintf( audioOptions, "%s -r 48000", audioOptions );
+				frequency = 48000;
+				if ( !strstr( audioencode, " -b " ) )
+					sprintf( audioOptions, "%s -b 224", audioOptions );
+			}
 			break;
 		}
 
@@ -390,13 +408,27 @@ ExportMJPEG::doExport( PlayList * playlist, int begin, int end, int every,
 		         deinterlace, videopipeInput, videoformat, interlace,
 		         isPAL ? 'p' : 'n', filename );
 	}
-	audiopipe = g_strdup_printf( "|%s %s -o \'%s\'.mp2", audioencode, audioOptions, filename );
-	if ( strcmp( multiplexer, "" ) )
+	if ( strstr( audioencode, "ffmpeg" ) )
 	{
-		multiplex = g_strdup_printf( "%s -f %d -o \'%s\'%%s.mpeg \'%s\'.mpv \'%s\'.mp2",
-		         multiplexer, videoformat, filename, filename, filename );
-		cleanup = g_strdup_printf( "rm -f \'%s\'.mpv \'%s\'.mp2 \'%s\'.wav",
-		         filename, filename, filename );
+		audiopipe = g_strdup_printf( "|%s -f wav -i pipe: %s -y \'%s\'.ac3", audioencode, audioOptions, filename );
+		if ( strcmp( multiplexer, "" ) )
+		{
+			multiplex = g_strdup_printf( "%s -f %d -o \'%s\'%%s.mpeg \'%s\'.mpv \'%s\'.ac3",
+					multiplexer, videoformat, filename, filename, filename );
+			cleanup = g_strdup_printf( "rm -f \'%s\'.mpv \'%s\'.ac3 \'%s\'.wav",
+					filename, filename, filename );
+		}
+	}
+	else if ( strstr( audioencode, "mp2enc" ) )
+	{
+		audiopipe = g_strdup_printf( "|%s %s -o \'%s\'.mp2", audioencode, audioOptions, filename );
+		if ( strcmp( multiplexer, "" ) )
+		{
+			multiplex = g_strdup_printf( "%s -f %d -o \'%s\'%%s.mpeg \'%s\'.mpv \'%s\'.mp2",
+					multiplexer, videoformat, filename, filename, filename );
+			cleanup = g_strdup_printf( "rm -f \'%s\'.mpv \'%s\'.mp2 \'%s\'.wav",
+					filename, filename, filename );
+		}
 	}
 
 	KinoAudioPipe *wav = KinoAudioFactory::CreateAudioPipe( PIPE_AUDIO_WAV );
@@ -412,7 +444,8 @@ ExportMJPEG::doExport( PlayList * playlist, int begin, int end, int every,
 		gchar *full;
 		char sceneString[ 20 ];
 		int sceneEnd = end;
-		bool userMplexSplit = ( strstr( multiplex, "-S" ) || strstr( multiplex, "--max-segment-size" ) );
+		bool userMplexSplit = ( multiplex != NULL && ( strstr( multiplex, "-S" ) || 
+			strstr( multiplex, "--max-segment-size" ) ) );
 
 		// Determine if we need to split by scene or not
 		// when splitting: Output is generated as fileNNN_MMM.mpeg where NNN is the
@@ -451,9 +484,11 @@ ExportMJPEG::doExport( PlayList * playlist, int begin, int end, int every,
 		}
 
 		cerr << ">>> Generated video pipe '" << videopipe << "'" << endl;
-		cerr << ">>> Generated audio pipe '" << audiopipe << "'" << endl;
-
-		mpeg->OpenAudio( audiopipe, channels, frequency, 2 );
+		if ( audiopipe )
+		{
+			cerr << ">>> Generated audio pipe '" << audiopipe << "'" << endl;
+			mpeg->OpenAudio( audiopipe, channels, frequency, 2 );
+		}
 		mpeg->OpenVideoPipe( videopipe, width, height, isY4Minterlaced );
 
 		int imagesize = width * height * 3;
@@ -463,19 +498,24 @@ ExportMJPEG::doExport( PlayList * playlist, int begin, int end, int every,
 		innerLoopUpdate( sceneBegin, begin, end, every );
 
 		// Determine correct amount of audio for duration
-		double adjustedRate = calculateAdjustedRate( playlist, frequency, sceneBegin, sceneEnd, every );
-		if ( !adjustedRate )
-			status = EXPORT_RESULT_ABORT;
-
-		// Setup a resampler
-		AsyncAudioResample<int16_ne_t,int16_le_t>* resampler = new AsyncAudioResample<int16_ne_t,int16_le_t>(
-			AUDIO_RESAMPLE_SRC_SINC_BEST_QUALITY, playlist, frequency, sceneBegin, sceneEnd, every );
-		if ( resampler->IsError() )
+		double adjustedRate = 0;
+		AsyncAudioResample<int16_ne_t,int16_le_t>* resampler = 0;
+		if ( audiopipe )
 		{
-			std::cerr << ">>> Resampler error: " << resampler->GetError() << std::endl;
-			exportPage->isExporting = false;
-			status = EXPORT_RESULT_FAILURE;
-			break;
+			adjustedRate = calculateAdjustedRate( playlist, frequency, sceneBegin, sceneEnd, every );
+			if ( !adjustedRate )
+				status = EXPORT_RESULT_ABORT;
+
+			// Setup a resampler
+			resampler = new AsyncAudioResample<int16_ne_t,int16_le_t>(
+				AUDIO_RESAMPLE_SRC_SINC_BEST_QUALITY, playlist, frequency, sceneBegin, sceneEnd, every );
+			if ( resampler->IsError() )
+			{
+				std::cerr << ">>> Resampler error: " << resampler->GetError() << std::endl;
+				exportPage->isExporting = false;
+				status = EXPORT_RESULT_FAILURE;
+				break;
+			}
 		}
 
 		/* Iterate over frames in scene */
@@ -485,14 +525,17 @@ ExportMJPEG::doExport( PlayList * playlist, int begin, int end, int every,
 			innerLoopUpdate( i, begin, end, every );
 			playlist->GetFrame( i, *frame );
 
-			int requestedSamples = frame->CalculateNumberSamples( frequency, j );
-			int nsamples = resampler->Process( adjustedRate, requestedSamples );
-			if ( nsamples > 0 && !mpeg->OutputAudioFrame( reinterpret_cast<int16_t *>(resampler->GetOutput()), 
-				nsamples * channels * sizeof(int16_t) ) )
+			if ( audiopipe && resampler )
 			{
-				modal_message( _( "Error writing to KINO/MJPEG audio filter - aborting." ) );
-				status = EXPORT_RESULT_FAILURE;
-				break;
+				int requestedSamples = frame->CalculateNumberSamples( frequency, j );
+				int nsamples = resampler->Process( adjustedRate, requestedSamples );
+				if ( nsamples > 0 && !mpeg->OutputAudioFrame( reinterpret_cast<int16_t *>(resampler->GetOutput()), 
+					nsamples * channels * sizeof(int16_t) ) )
+				{
+					modal_message( _( "Error writing to KINO/MJPEG audio filter - aborting." ) );
+					status = EXPORT_RESULT_FAILURE;
+					break;
+				}
 			}
 
 			if ( exportPage->isExporting )
@@ -517,7 +560,8 @@ ExportMJPEG::doExport( PlayList * playlist, int begin, int end, int every,
 			exportPage->isExporting = false;
 
 		// Try to finish the stream to create a valid mpeg if possible
-		mpeg->CloseAudio();
+		if ( audiopipe )
+			mpeg->CloseAudio();
 		mpeg->CloseVideo();
 		delete resampler;
 		resampler = 0;
@@ -535,7 +579,7 @@ ExportMJPEG::doExport( PlayList * playlist, int begin, int end, int every,
 			g_free( full );
 		}
 
-		if ( Usercleanup )
+		if ( Usercleanup && cleanup != NULL && strcmp( cleanup, "" ) )
 			mpeg->ExecuteCommand( cleanup );
 		
 		// Move to start of next scene
