@@ -343,7 +343,7 @@ enum export_result ExportPipe::doExport( PlayList *playlist, int begin, int end,
 	
 		// first call to innerLoopUpdate initializes progress tracker, which
 		// we want to do because calculateAdjustedRate generates paused time.
-		innerLoopUpdate( begin, begin, end, every );
+		innerLoopUpdate( begin, begin, end + (end - begin + 1) * (passes - 1), every );
 
 		// Determine correct amount of audio for duration
 		double adjustedRate = calculateAdjustedRate( playlist, info.frequency, begin, end, every );
@@ -385,8 +385,10 @@ enum export_result ExportPipe::doExport( PlayList *playlist, int begin, int end,
 			for ( i = begin, j = 0; success && i <= end && exportPage->isExporting; i += every, j++ )
 			{
 				// Call innerLoopUpdate
-				if ( passes )
-					innerLoopUpdate( i, begin, end, every, pass == 1 ? _("Exporting (pass 1)") : _("Exporting (pass 2)") );
+				if ( passes > 1 )
+					innerLoopUpdate( i + (end - begin + 1) / every * (pass - 1),
+						begin, end + (end - begin + 1), every,
+						pass == 1 ? _("Exporting (pass 1)") : _("Exporting (pass 2)") );
 				else
 					innerLoopUpdate( i, begin, end, every );
 	
