@@ -24,10 +24,15 @@
 #include <config.h>
 #endif
 
+#include <vector>
+#include <string>
+
 #include <gtk/gtk.h>
 
 #include "export.h"
 #include "page_export.h"
+#include "kino_common.h"
+#include "playlist.h"
 
 class DVPipeTool;
 
