@@ -953,7 +953,7 @@ void PageMagickTransition::PreGetFrame( int keyPosition )
 	if ( animateKey )
 	{
 		if ( keyPosition > -1 )
-			info->postFrame = keyPosition;
+			info->postFrame = info->end + keyPosition;
 		info->GetPostFrame( keyFrame );
 	}
 	info->postFrame ++;
@@ -992,7 +992,7 @@ public:
 	void PreGetFrame( int keyPosition )
 	{
 		if ( keyPosition > -1 )
-			info->postFrame = keyPosition;
+			info->postFrame = info->end + keyPosition;
 		else
 			info->postFrame ++;
 	}
@@ -1117,8 +1117,7 @@ void PageMagickAudioTransition::GetFrame( int16_t **audio, int i, int& samples,
 											AUDIO_RESAMPLE_SRC_SINC_BEST_QUALITY, info->frequency, false );
 			resampler->Resample( *infoFrame );
 			int16_t *p = resampler->output;
-			if ( resampler->size / info->channels / 2 < samples )
-				samples = resampler->size / info->channels / 2;
+			samples = resampler->size / info->channels / 2;
 			for ( int s = 0; s < samples; s++ )
 				for ( int c = 0; c < info->channels; c++ )
 					audio_buffers[ c ][ s ] = *p++;
@@ -1443,9 +1442,9 @@ PageMagick::PageMagick( KinoCommon *common ) :
 	GtkWidget *widget = lookup_widget( window, "notebook_magick_frames" );
 	g_signal_connect_after( G_OBJECT( widget ), "switch_page", G_CALLBACK( on_notebook_magick_switch_page ), this );
 	widget = lookup_widget( window, "notebook_magick_video" );
-	g_signal_connect( G_OBJECT( widget ), "switch_page", G_CALLBACK( on_notebook_magick_switch_page ), NULL );
+	g_signal_connect_after( G_OBJECT( widget ), "switch_page", G_CALLBACK( on_notebook_magick_switch_page ), NULL );
 	widget = lookup_widget( window, "notebook_magick_audio" );
-	g_signal_connect( G_OBJECT( widget ), "switch_page", G_CALLBACK( on_notebook_magick_switch_page ), NULL );
+	g_signal_connect_after( G_OBJECT( widget ), "switch_page", G_CALLBACK( on_notebook_magick_switch_page ), NULL );
 
 	widget = lookup_widget( window, "checkbutton_magick_frame_limit" );
 	g_signal_connect( G_OBJECT( widget ), "clicked", G_CALLBACK( on_time_range_changed ), NULL );
@@ -1651,8 +1650,12 @@ void PageMagick::movedToFrame( int frame_number )
 		common->getPageEditor()->ResetBar();
 		common->hasListChanged = FALSE;
 		if ( common->getPlayList() ->GetNumFrames() > 0 )
-			selectScene( common->g_currentFrame );
-
+		{
+			std::vector<int> scenes = common->getPageEditor()->GetScene();
+			int i = 0;
+			for ( i = 0; i < int( scenes.size() ) && frame_number >= scenes[ i ]; i++ );
+			selectScene( i );
+		}
 		GtkEntry *startSpin = GTK_ENTRY( lookup_widget( window, "spinbutton_magick_start" ) );
 		GtkEntry *endSpin = GTK_ENTRY( lookup_widget( window, "spinbutton_magick_end" ) );
 		GtkAdjustment *adjust = gtk_spin_button_get_adjustment( GTK_SPIN_BUTTON( startSpin ) );
@@ -1714,7 +1717,7 @@ void PageMagick::PreviewFrame()
 			if ( frame_number > info->end )
 				frame_number = info->end;
 			frames->GetFrame( pixels, info->width, info->height, NULL, frame_number );
-			image->PreGetFrame( frame_number );
+			image->PreGetFrame( frame_number - info->begin );
 			image->GetFrame( pixels, frame_number );
 			ShowImage( area, pixels, info->width, info->height );
 			delete[] pixels;
@@ -1790,6 +1793,7 @@ void PageMagick::StartPreview()
 			previewing = true;
 			restart = false;
 
+			if ( previewPosition <= 1 )
 			for ( int i = info->begin - atoi( gtk_entry_get_text( contextSpin ) );
 			        i < info->begin && gtk_toggle_button_get_active( contextButton ) && previewing;
 			        i ++ )
@@ -1814,8 +1818,8 @@ void PageMagick::StartPreview()
 					gtk_main_iteration();
 			}
 
-			int frame_number = info->begin;
-			for ( double i = ( double ) info->begin; 
+			int frame_number = info->begin + previewPosition;
+			for ( double i = ( double ) info->begin + previewPosition; 
 				frame_number <= info->end && previewing; 
 				frame_number = ( int )( ( i += info->increment ) + 0.5 ) )
 			{
@@ -1871,6 +1875,8 @@ void PageMagick::StartPreview()
 				while ( gtk_events_pending() )
 					gtk_main_iteration();
 			}
+			if ( previewing )
+				previewPosition = 0;
 		}
 		while ( ( previewing && gtk_toggle_button_get_active( loopButton ) ) || restart );
 	}
@@ -2232,29 +2238,12 @@ void PageMagick::selectScene( int i )
 
 	if ( GTK_WIDGET_SENSITIVE( lookup_widget( window, "hpaned_magick" ) ) )
 	{
-		GtkNotebook * notebook = GTK_NOTEBOOK( lookup_widget( this->window, "notebook_magick_frames" ) );
-		int page = gtk_notebook_get_current_page( notebook );
+		GtkEntry * startSpin = GTK_ENTRY( lookup_widget( window, "spinbutton_magick_start" ) );
+		GtkEntry *endSpin = GTK_ENTRY( lookup_widget( window, "spinbutton_magick_end" ) );
 
-		if ( page == 0 )
-		{
-			GtkEntry * startSpin = GTK_ENTRY( lookup_widget( window, "spinbutton_magick_start" ) );
-			GtkEntry *endSpin = GTK_ENTRY( lookup_widget( window, "spinbutton_magick_end" ) );
+		gtk_spin_button_set_value( GTK_SPIN_BUTTON( startSpin ), begin );
+		gtk_spin_button_set_value( GTK_SPIN_BUTTON( endSpin ), end );
 
-			gtk_spin_button_set_value( GTK_SPIN_BUTTON( startSpin ), begin );
-			gtk_spin_button_set_value( GTK_SPIN_BUTTON( endSpin ), end );
-		}
-		else if ( page == 1 )
-		{
-/* Commented to simplify UI to always create before current scene
-			GtkToggleButton * rangeToggle = GTK_TOGGLE_BUTTON( lookup_widget( window, "radiobutton_magick_create_before" ) );
-			GtkEntry *startSpin = GTK_ENTRY( lookup_widget( window, "spinbutton_magick_create_before" ) );
-			GtkAdjustment *adjust = gtk_spin_button_get_adjustment( GTK_SPIN_BUTTON( startSpin ) );
-			gtk_toggle_button_set_active( rangeToggle, TRUE );
-			adjust->lower = 0;
-			adjust->upper = scene[ scene.size() - 1 ];
-			gtk_spin_button_set_value( GTK_SPIN_BUTTON( startSpin ), begin );
-			g_signal_emit_by_name( adjust, "changed" );*/
-		}
 		if ( previewing )
 		{
 			restart = true;
