@@ -47,11 +47,11 @@ using std::endl;
 #define TRIM_ADJ_IN 1
 #define TRIM_ADJ_OUT 2
 
-extern KinoCommon *common;
-
 extern "C"
 {
 #include "support.h"
+
+	extern KinoCommon *common;
 	extern struct navigate_control g_nav_ctl;
 	extern char cmd[];
 	static char lastcmd[ 256 ] = { 0 };
@@ -1036,6 +1036,7 @@ void PageTrim::showFrame( int position, Frame& frame )
 	{
 		getFrameDisplayer() ->Put( frame, GTK_WIDGET( frameArea ), TRUE );
 		common->showFrameInfo( position );
+		skipPosUpdate = TRUE;
 		gtk_adjustment_set_value( trim_adj[ TRIM_ADJ_POS ], ( gfloat ) position );
 	}
 }
@@ -1876,14 +1877,16 @@ gboolean PageTrim::processCommand( char *command )
 
 	else if ( strcmp( cmd, "Ctrl+J" ) == 0 && currentScene != -1 )
 	{
+		int newScene = getSceneIndex() + 1;
 		common->keyboardFeedback( cmd, _( "Split scene before frame" ) );
 		if ( pos >= in && pos <= out &&
 			common->getPlayList() ->SplitSceneBefore( common->g_currentFrame ) )
 		{
 			GetEditorBackup() ->Store( common->getPlayList() );
 			common->hasListChanged = TRUE;
-			movedToFrame( pos );
 			g_signal_emit_by_name( trim_adj[ TRIM_ADJ_POS ], "value-changed" );
+			selectScene( newScene );
+			common->videoStartOfScene( );
 		}
 		cmd[ 0 ] = 0;
 	}
