@@ -50,6 +50,8 @@ using std::map;
 #include "filehandler.h"
 #include "frame.h"
 
+const xmlChar* SMIL20_NAMESPACE_HREF = reinterpret_cast< const xmlChar* >( "http://www.w3.org/2001/SMIL20/Language" );
+
 /** The file map implementation - this class is responsible for maintaining the list of
 	open files associated to a project.
 */
@@ -301,7 +303,7 @@ string directory_utils::expand_directory( const string directory )
 	return output;
 }
 
-typedef bool ( *callback ) ( xmlNodePtr node, void *p );
+typedef bool ( *callback ) ( xmlNodePtr node, void *p, bool *freed );
 
 typedef struct
 {
@@ -340,7 +342,7 @@ MovieInfo;
     \param p pointer to MovieInfo struct
     \result true if file has been found and xml tree walk is done */
 
-static bool findFile( xmlNodePtr node, void *p )
+static bool findFile( xmlNodePtr node, void *p, bool *freed )
 {
 	MovieInfo * data = ( MovieInfo* ) p;
 
@@ -412,7 +414,7 @@ static bool findFile( xmlNodePtr node, void *p )
     \param p pointer to a string containing the project directory
     \result true if file has been found and xml tree walk is done */
 
-static bool fillMap( xmlNodePtr node, void *p )
+static bool fillMap( xmlNodePtr node, void *p, bool *freed )
 {
 	if ( xmlStrcmp( node->name, ( const xmlChar* ) "video" ) == 0 )
 	{
@@ -468,6 +470,7 @@ static bool fillMap( xmlNodePtr node, void *p )
 					<< " - removing from list" << endl;
 					xmlUnlinkNode( node );
 					xmlFreeNode( node );
+					*freed = true;
 				}
 			}
 		}
@@ -489,7 +492,7 @@ static bool fillMap( xmlNodePtr node, void *p )
     If the scene has been found in the playlist, the file name 
     and first frame number are returned in the private data. */
 
-static bool findSceneStart( xmlNodePtr node, void *p )
+static bool findSceneStart( xmlNodePtr node, void *p, bool *freed )
 {
 	int fileCount = 0;
 	MovieInfo *data = ( MovieInfo* ) p;
@@ -502,7 +505,7 @@ static bool findSceneStart( xmlNodePtr node, void *p )
 
 		data->sequence = node;
 
-		node = node->xmlChildrenNode;
+		node = node->children;
 		while ( node != NULL )
 		{
 			if ( xmlStrcmp( node->name, ( const xmlChar* ) "video" ) == 0 )
@@ -562,7 +565,7 @@ static bool findSceneStart( xmlNodePtr node, void *p )
 }
 
 
-static bool findSceneEnd( xmlNodePtr node, void *p )
+static bool findSceneEnd( xmlNodePtr node, void *p, bool *freed )
 {
 	bool found = false;
 	xmlChar *src = NULL;
@@ -575,7 +578,7 @@ static bool findSceneEnd( xmlNodePtr node, void *p )
 
 		data->sequence = node;
 
-		node = node->xmlChildrenNode;
+		node = node->children;
 		while ( node != NULL )
 		{
 			if ( xmlStrcmp( node->name, ( const xmlChar* ) "video" ) == 0 )
@@ -640,7 +643,7 @@ static bool findSceneEnd( xmlNodePtr node, void *p )
  
     \note This code requires a <video> node format that is not defined in smil. */
 
-static bool countFrames( xmlNodePtr node, void *p )
+static bool countFrames( xmlNodePtr node, void *p, bool *freed )
 {
 	if ( xmlStrcmp( node->name, ( const xmlChar* ) "video" ) == 0 )
 	{
@@ -686,7 +689,7 @@ typedef EliInfos::iterator EliInfosIterator;
     <video src="file.avi" clipBegin="200" clipEnd="800" \>
  
     \note This code requires a <video> node format that is not defined in smil. */
-static bool convertEli( xmlNodePtr node, void *p )
+static bool convertEli( xmlNodePtr node, void *p, bool *freed )
 {
 	if ( xmlStrcmp( node->name, ( const xmlChar* ) "video" ) == 0 )
 	{
@@ -719,7 +722,87 @@ static bool convertEli( xmlNodePtr node, void *p )
 	return false;
 }
 
+static bool convertFramesToSmilTime( xmlNodePtr node, void *data, bool *freed )
+{
+	if ( xmlStrcmp( node->name, ( const xmlChar* ) "video" ) == 0 )
+	{
+		Frame *frame = GetFramePool( )->GetFrame( );
+		xmlChar *src = xmlGetProp( node, ( const xmlChar* ) "src" );
+		string index( ( char* ) src );
+		xmlFree( src );
+		FileHandler *mediaFile = GetFileMap()->GetMap() [ index ];
+		mediaFile->GetFrame( *frame, 0 );
+		SMIL::MediaClippingTime time;
+		time.setFramerate( frame->GetFrameRate() );
+		GetFramePool( )->DoneWithFrame( frame );
 
+		xmlChar *prop = xmlGetProp( node, ( const xmlChar* ) "clipBegin" );
+		if ( prop )
+		{
+			std::string newValue = time.parseFramesToString( atoi( ( const char* ) prop ), SMIL::Time::TIME_FORMAT_CLOCK );
+			xmlFree( prop );
+			xmlSetProp( node, ( const xmlChar* ) "clipBegin", ( const xmlChar* ) newValue.c_str() );
+		}
+		prop = xmlGetProp( node, ( const xmlChar* ) "clipEnd" );
+		if ( prop )
+		{
+			std::string newValue = time.parseFramesToString( atoi( ( const char* ) prop ), SMIL::Time::TIME_FORMAT_CLOCK );
+			xmlFree( prop );
+			xmlSetProp( node, ( const xmlChar* ) "clipEnd", ( const xmlChar* ) newValue.c_str() );
+		}
+	}
+	return false;
+}
+
+static bool convertSmilTimeToFrames( xmlNodePtr node, void *data, bool *freed )
+{
+	if ( xmlStrcmp( node->name, ( const xmlChar* ) "video" ) == 0 )
+	{
+		Frame *frame = GetFramePool( )->GetFrame( );
+		xmlChar *src = xmlGetProp( node, ( const xmlChar* ) "src" );
+		string index( ( char* ) src );
+		xmlFree( src );
+		FileHandler *mediaFile = GetFileMap()->GetMap() [ index ];
+		mediaFile->GetFrame( *frame, 0 );
+		SMIL::MediaClippingTime time;
+		time.setFramerate( frame->GetFrameRate() );
+		GetFramePool( )->DoneWithFrame( frame );
+
+		xmlChar *prop = xmlGetProp( node, ( const xmlChar* ) "clipBegin" );
+		if ( prop )
+		{
+			time.parseValue( ( const char* ) prop );
+			xmlFree( prop );
+			std::string newValue = time.toString( SMIL::Time::TIME_FORMAT_FRAMES );
+			xmlSetProp( node, ( const xmlChar* ) "clipBegin", ( const xmlChar* ) newValue.c_str() );
+		}
+		prop = xmlGetProp( node, ( const xmlChar* ) "clipEnd" );
+		if ( prop )
+		{
+			time.parseValue( ( const char* ) prop );
+			xmlFree( prop );
+			std::string newValue = time.toString( SMIL::Time::TIME_FORMAT_FRAMES );
+			xmlSetProp( node, ( const xmlChar* ) "clipEnd", ( const xmlChar* ) newValue.c_str() );
+		}
+	}
+	return false;
+}
+
+static bool clone( xmlNodePtr node, void *data, bool *freed )
+{
+	xmlNodePtr* parent = (xmlNodePtr*) data;
+
+	xmlNodePtr child = xmlNewNode( NULL, node->name );
+	xmlAddChild( *parent, child );
+	for ( xmlAttr* attr = node->properties; attr; attr = attr->next )
+		xmlNewProp( child, attr->name, xmlGetProp( attr->parent, attr->name) );
+	if ( node->children ) // next iteration in depth-first traversal will be a child
+		*parent = child;
+	else if ( node == node->parent->last ) // last sibling
+		*parent = (*parent)->parent;
+	
+	return false;
+}
 
 /** Walk the xml tree
  
@@ -741,10 +824,12 @@ static bool parse( xmlNodePtr node, callback func, void *p )
 
 	while ( node != NULL && done == false )
 	{
-		done = ( *func ) ( node, p );
-		if ( done == false && node->xmlChildrenNode != NULL )
-			done = parse( node->xmlChildrenNode, func, p );
-		node = node->next;
+		bool freed = false;
+		xmlNodePtr next = node->next;
+		done = ( *func ) ( node, p, &freed );
+		if ( !done && !freed && node->children )
+			done = parse( node->children, func, p );
+		node = next;
 	}
 	return done;
 }
@@ -761,8 +846,9 @@ PlayList::PlayList() : dirty( false ), doc_name( "" ), count( 0 )
 
 	doc = xmlNewDoc( ( const xmlChar* ) "1.0" );
 	root = xmlNewNode( NULL, ( const xmlChar* ) "smil" );
-	ns = xmlNewNs( root, ( const xmlChar* ) "http://www.w3.org/2001/SMIL20/Language", ( const xmlChar* ) "smil2" );
+	ns = xmlNewNs( root, SMIL20_NAMESPACE_HREF, ( const xmlChar* ) NULL );
 	xmlDocSetRootElement( doc, root );
+	xmlAddChild( root, xmlNewNode( NULL, ( const xmlChar* ) "body" ) );
 }
 
 
@@ -770,8 +856,14 @@ PlayList::PlayList() : dirty( false ), doc_name( "" ), count( 0 )
 
 PlayList::PlayList( const PlayList& playList )
 {
-	// cerr << "*PlayList::PlayList(const PlayList& playList)" << endl;
-	doc = xmlCopyDoc( playList.doc, true );
+	xmlNsPtr	ns;
+	xmlNodePtr	root;
+
+	doc = xmlNewDoc( ( const xmlChar* ) "1.0" );
+	root = xmlNewNode( NULL, ( const xmlChar* ) "smil" );
+	ns = xmlNewNs( root, ( const xmlChar* ) SMIL20_NAMESPACE_HREF, ( const xmlChar* ) NULL );
+	xmlDocSetRootElement( doc, root );
+	parse( playList.GetBody(), clone, &root );
 	dirty = playList.dirty;
 	doc_name = playList.GetDocName( );
 	RefreshCount( );
@@ -786,8 +878,15 @@ PlayList& PlayList::operator=( const PlayList& playList )
 
 	if ( doc != playList.doc )
 	{
+		xmlNsPtr	ns;
+		xmlNodePtr	root;
+
 		xmlFreeDoc( doc );
-		doc = xmlCopyDoc( playList.doc, true );
+		doc = xmlNewDoc( ( const xmlChar* ) "1.0" );
+		root = xmlNewNode( NULL, ( const xmlChar* ) "smil" );
+		ns = xmlNewNs( root, ( const xmlChar* ) SMIL20_NAMESPACE_HREF, ( const xmlChar* ) NULL );
+		xmlDocSetRootElement( doc, root );
+		parse( playList.GetBody(), clone, &root );
 		dirty = playList.dirty;
 		doc_name = playList.GetDocName( );
 		RefreshCount( );
@@ -809,11 +908,21 @@ PlayList::~PlayList()
 	}
 }
 
+/** Get the SMIL body element
+
+    \return a node pointer to the body element */
+
+xmlNodePtr PlayList::GetBody( ) const
+{
+	return xmlDocGetRootElement( doc )->children;
+}
+
+
 void PlayList::RefreshCount( )
 {
 	count = 0;
 	if ( doc != NULL )
-		parse( xmlDocGetRootElement( doc ), countFrames, &count );
+		parse( GetBody(), countFrames, &count );
 }
 
 /** Counts the number of frames in the playlist
@@ -836,7 +945,7 @@ char* PlayList::GetFileNameOfFrame( int frameNum ) const
 	data.absEnd = 0;
 	data.absFrame = frameNum;
 
-	parse( xmlDocGetRootElement( doc ), findFile, &data );
+	parse( GetBody(), findFile, &data );
 	return data.fileName;
 }
 
@@ -861,7 +970,7 @@ bool PlayList::GetFrame( int frameNum, Frame &frame )
 	data.absEnd = 0;
 	data.absFrame = frameNum;
 
-	parse( xmlDocGetRootElement( doc ), findFile, &data );
+	parse( GetBody(), findFile, &data );
 
 	if ( strcmp( data.fileName, "" ) )
 	{
@@ -893,7 +1002,7 @@ bool PlayList::GetMediaObject( int frameNum, FileHandler **media )
 	data.absEnd = 0;
 	data.absFrame = frameNum;
 
-	parse( xmlDocGetRootElement( doc ), findFile, &data );
+	parse( GetBody(), findFile, &data );
 
 	if ( strcmp( data.fileName, "" ) )
 	{
@@ -916,7 +1025,7 @@ int PlayList::GetClipBegin( int frameNum ) const
 	data.absEnd = 0;
 	data.absFrame = frameNum;
 
-	if ( parse( xmlDocGetRootElement( doc ), findSceneStart, &data ) )
+	if ( parse( GetBody(), findSceneStart, &data ) )
 		return data.clipBegin;
 	else
 		return 0;
@@ -932,7 +1041,7 @@ int PlayList::GetClipEnd( int frameNum ) const
 	data.absEnd = 0;
 	data.absFrame = frameNum;
 
-	if ( parse( xmlDocGetRootElement( doc ), findSceneEnd, &data ) )
+	if ( parse( GetBody(), findSceneEnd, &data ) )
 		return data.clipEnd;
 	else
 		return 0;
@@ -948,7 +1057,7 @@ bool PlayList::SetClipBegin( int frameNum, const char* value )
 	data.absEnd = 0;
 	data.absFrame = frameNum;
 
-	if ( parse( xmlDocGetRootElement( doc ), findSceneStart, &data ) )
+	if ( parse( GetBody(), findSceneStart, &data ) )
 	{
 		xmlSetProp( data.video, ( const xmlChar * ) "clipBegin", ( const xmlChar * ) value );
 		RefreshCount( );
@@ -968,7 +1077,7 @@ bool PlayList::SetClipEnd( int frameNum, const char* value )
 	data.absEnd = 0;
 	data.absFrame = frameNum;
 
-	if ( parse( xmlDocGetRootElement( doc ), findSceneEnd, &data ) )
+	if ( parse( GetBody(), findSceneEnd, &data ) )
 	{
 		xmlSetProp( data.video, ( const xmlChar * ) "clipEnd", ( const xmlChar * ) value );
 		RefreshCount( );
@@ -990,7 +1099,7 @@ int PlayList::FindStartOfScene( int frameNum ) const
 	data.absEnd = 0;
 	data.absFrame = frameNum;
 
-	parse( xmlDocGetRootElement( doc ), findSceneStart, &data );
+	parse( GetBody(), findSceneStart, &data );
 
 	if ( strcmp( data.fileName, "" ) )
 		return data.absBegin;
@@ -1009,7 +1118,7 @@ int PlayList::FindEndOfScene( int frameNum ) const
 	data.absEnd = 0;
 	data.absFrame = frameNum;
 
-	parse( xmlDocGetRootElement( doc ), findSceneEnd, &data );
+	parse( GetBody(), findSceneEnd, &data );
 
 	if ( strcmp( data.fileName, "" ) )
 		return data.absEnd;
@@ -1035,7 +1144,7 @@ void PlayList::AutoSplit( int start, int end )
 	firstFile.absEnd = 0;
 	firstFile.absFrame = start;
 
-	parse( xmlDocGetRootElement( doc ), findFile, &firstFile );
+	parse( GetBody(), findFile, &firstFile );
 	string index1( ( char* ) firstFile.fileName );
 	FileHandler *mediaFile1 = GetFileMap() ->GetMap() [ index1 ];
 	mediaFile1->GetFrame( *frame, firstFile.clipFrame );
@@ -1047,7 +1156,7 @@ void PlayList::AutoSplit( int start, int end )
 	lastFile.absEnd = 0;
 	lastFile.absFrame = end;
 
-	parse( xmlDocGetRootElement( doc ), findFile, &lastFile );
+	parse( GetBody(), findFile, &lastFile );
 
 	string index2( ( char* ) lastFile.fileName );
 	FileHandler *mediaFile2 = GetFileMap() ->GetMap() [ index2 ];
@@ -1085,7 +1194,7 @@ void PlayList::AutoSplit( int start, time_t startTime, int end, time_t endTime,
 				memset( &midFile, 0, sizeof( MovieInfo ) );
 				midFile.absFrame = mid;
 
-				parse( xmlDocGetRootElement( doc ), findFile, &midFile );
+				parse( GetBody(), findFile, &midFile );
 
 				string index( ( char* ) midFile.fileName );
 				FileHandler *mediaFile = GetFileMap() ->GetMap() [ index ];
@@ -1124,14 +1233,14 @@ bool PlayList::SplitSceneBefore( int frameNum )
 	data.absBegin = 0;
 	data.absEnd = 0;
 	data.absFrame = frameNum;
-	parse( xmlDocGetRootElement( doc ), findSceneStart, &data );
+	parse( GetBody(), findSceneStart, &data );
 	int begin = data.absBegin;
 
 	memset( &data, 0, sizeof( MovieInfo ) );
 	data.absBegin = 0;
 	data.absEnd = 0;
 	data.absFrame = frameNum;
-	parse( xmlDocGetRootElement( doc ), findSceneEnd, &data );
+	parse( GetBody(), findSceneEnd, &data );
 	int end = data.absEnd;
 
 	if ( strcmp( data.fileName, "" ) && begin != frameNum )
@@ -1139,20 +1248,17 @@ bool PlayList::SplitSceneBefore( int frameNum )
 
 		dirty = true;
 
-		// duplicate the whole scene.
+		// Copy the right hand side of the current scene
+ 		xmlNode *firstSequence = data.sequence;
+		PlayList playlist;
+		GetPlayList( frameNum, end, playlist );
 
-		xmlNode *firstSequence = data.sequence;
-		xmlNode *secondSequence = xmlCopyNodeList( firstSequence );
-		xmlAddNextSibling( firstSequence, secondSequence );
+		// Paste it after the current scene
+		xmlAddNextSibling( firstSequence, playlist.GetBody()->children );
 
 		// in the first sequence, delete from frameNum to end of scene
-
 		Delete( frameNum, end );
 
-		// in the second sequence, delete from start of scene to frameNum - 1
-
-		Delete( frameNum, frameNum - begin + frameNum - 1 );
-
 		return true;
 	}
 	else
@@ -1176,20 +1282,20 @@ bool PlayList::JoinScenesAt( int frameNum )
 	scene1.absBegin = 0;
 	scene1.absEnd = 0;
 	scene1.absFrame = frameNum;
-	parse( xmlDocGetRootElement( doc ), findSceneStart, &scene1 );
+	parse( GetBody(), findSceneStart, &scene1 );
 
 	memset( &scene2, 0, sizeof( MovieInfo ) );
 	scene2.absBegin = 0;
 	scene2.absEnd = 0;
 	scene2.absFrame = frameNum;
-	parse( xmlDocGetRootElement( doc ), findSceneEnd, &scene2 );
+	parse( GetBody(), findSceneEnd, &scene2 );
 	int end = scene2.absEnd + 1;
 
 	memset( &scene2end, 0, sizeof( MovieInfo ) );
 	scene2end.absBegin = 0;
 	scene2end.absEnd = 0;
 	scene2end.absFrame = end;
-	parse( xmlDocGetRootElement( doc ), findSceneEnd, &scene2end );
+	parse( GetBody(), findSceneEnd, &scene2end );
 
 	if ( scene1.sequence != scene2end.sequence )
 	{
@@ -1201,19 +1307,15 @@ bool PlayList::JoinScenesAt( int frameNum )
 
 		// concatenate the contents of scene2 into scene1
 		xmlNode *lastchild = xmlGetLastChild( scene1.sequence );
-		xmlNode *secondSequence = xmlCopyNodeList( scene2end.sequence->children );
-
-		// Delete scene2
-		Delete( scene2.absBegin, scene2end.absEnd );
-
-		while ( secondSequence != NULL )
+		xmlNodePtr next = NULL;
+		for ( xmlNodePtr ptr = scene2end.sequence->children; ptr != NULL; ptr = next )
 		{
-			xmlNode * backup = secondSequence->next;
-			lastchild = xmlAddNextSibling( lastchild, secondSequence );
-			secondSequence = backup;
+			next = ptr->next;
+			lastchild = xmlAddNextSibling( lastchild, ptr );
+			ptr = next;
 		}
-
-		xmlFreeNode( secondSequence );
+		xmlUnlinkNode( scene2end.sequence );
+		xmlFreeNode( scene2end.sequence );
 		RefreshCount( );
 
 		return true;
@@ -1232,6 +1334,7 @@ bool PlayList::JoinScenesAt( int frameNum )
  
     \param first number of first frame
     \param last number of last frame
+    \param playlist the playlist object to be filled
     \return true if the frames could be copied, false otherwise
 */
 
@@ -1252,29 +1355,34 @@ bool PlayList::GetPlayList( int first, int last, PlayList &playlist ) const
 	firstFile.absEnd = 0;
 	firstFile.absFrame = first;
 
-	parse( xmlDocGetRootElement( doc ), findFile, &firstFile );
+	parse( GetBody(), findFile, &firstFile );
 
 	memset( &lastFile, 0, sizeof( MovieInfo ) );
 	lastFile.absBegin = 0;
 	lastFile.absEnd = 0;
 	lastFile.absFrame = last;
 
-	parse( xmlDocGetRootElement( doc ), findFile, &lastFile );
+	parse( GetBody(), findFile, &lastFile );
 
 	if ( strcmp( firstFile.fileName, "" ) && strcmp( lastFile.fileName, "" ) )
 	{
 
-		xmlNodePtr srcNode = xmlDocGetRootElement( doc );
-		xmlNodePtr dstNode = xmlDocGetRootElement( playlist.doc );
+		xmlNodePtr srcNode = GetBody();
+		xmlNodePtr dstNode = playlist.GetBody();
+		xmlNodePtr nextSeq = NULL;
 
-		for ( xmlNodePtr srcSeq = srcNode->xmlChildrenNode; srcSeq != NULL; srcSeq = srcSeq->next )
+		for ( xmlNodePtr srcSeq = srcNode->children; srcSeq != NULL; srcSeq = nextSeq )
 		{
+			nextSeq = srcSeq->next;
 			if ( xmlStrcmp( srcSeq->name, ( const xmlChar* ) "seq" ) == 0 )
 			{
 				xmlNodePtr seq = xmlNewNode( NULL, ( const xmlChar* ) "seq" );
 				xmlAddChild( dstNode, seq );
-				for ( xmlNodePtr srcVideo = srcSeq->xmlChildrenNode; srcVideo != NULL; srcVideo = srcVideo->next )
+				xmlNodePtr nextVideo = NULL;
+
+				for ( xmlNodePtr srcVideo = srcSeq->children; srcVideo != NULL; srcVideo = nextVideo )
 				{
+					nextVideo = srcVideo->next;
 					if ( xmlStrcmp( srcVideo->name, ( const xmlChar* ) "video" ) == 0 )
 					{
 
@@ -1282,7 +1390,10 @@ bool PlayList::GetPlayList( int first, int last, PlayList &playlist ) const
 
 						if ( copyFlag && srcVideo != firstFile.video && srcVideo != lastFile.video )
 						{
-							xmlAddChild( seq, xmlCopyNode( srcVideo, 1 ) );
+							xmlNodePtr video = xmlNewNode( NULL, ( const xmlChar* ) "video" );
+							xmlAddChild( seq, video );
+							for ( xmlAttr* attr = srcVideo->properties; attr; attr = attr->next )
+								xmlNewProp( video, attr->name, xmlGetProp( attr->parent, attr->name) );
 						}
 
 						// case 2: selection contains more than one file and this is the first file
@@ -1339,7 +1450,7 @@ bool PlayList::GetPlayList( int first, int last, PlayList &playlist ) const
 
 				// if this sequence does not have any video clips, remove it
 
-				if ( seq->xmlChildrenNode == NULL )
+				if ( seq->children == NULL )
 				{
 					xmlUnlinkNode( seq );
 					xmlFreeNode( seq );
@@ -1354,7 +1465,7 @@ bool PlayList::GetPlayList( int first, int last, PlayList &playlist ) const
 		}
 		// PASS PATH
 		string path = directory_utils::get_directory_from_file( GetDocName() );
-		parse( xmlDocGetRootElement( playlist.doc ), fillMap, &path );
+		parse( playlist.GetBody(), fillMap, &path );
 	}
 	playlist.RefreshCount( );
 	return true;
@@ -1381,7 +1492,7 @@ bool PlayList::InsertPlayList( PlayList &playlist, int before )
 
 	// PASS PATH
 	string path = directory_utils::get_directory_from_file( GetDocName() );
-	parse( xmlDocGetRootElement( playlist.doc ), fillMap, &path );
+	parse( playlist.GetBody(), fillMap, &path );
 
 	MovieInfo file;
 
@@ -1393,10 +1504,9 @@ bool PlayList::InsertPlayList( PlayList &playlist, int before )
 	file.video = NULL;
 
 	// Fill the map with any new files now, before we change the doc
-	parse( xmlDocGetRootElement( doc ), findFile, &file );
-
-	xmlNodePtr node = xmlDocGetRootElement( playlist.doc );
+	parse( GetBody(), findFile, &file );
 
+	xmlNodePtr node = playlist.GetBody();
 	bool first = true;
 	xmlNodePtr next = NULL;
 	xmlNodePtr sequence = file.sequence;
@@ -1429,8 +1539,12 @@ bool PlayList::InsertPlayList( PlayList &playlist, int before )
 
 		if ( first && sequence == NULL )
 		{
-			ptr = xmlCopyNode( ptr, -1 );
-			sequence = xmlAddChild( xmlDocGetRootElement( doc ), ptr );
+			// This strange approach avoids using xmlCopyNode, which adds extra namespace declarations
+			xmlNodePtr tmp = xmlNewNode( NULL, ( const xmlChar* ) "seq" );
+			xmlAddChild( GetBody(), tmp );
+			sequence = xmlAddNextSibling( tmp, ptr );
+			xmlUnlinkNode( tmp );
+			xmlFreeNode( tmp );
 		}
 		else if ( first && before == file.absBegin && before != ( file.absEnd + 1 ) )
 		{
@@ -1454,7 +1568,7 @@ bool PlayList::InsertPlayList( PlayList &playlist, int before )
 			file.sequence = NULL;
 			file.video = NULL;
 
-			parse( xmlDocGetRootElement( doc ), findFile, &file );
+			parse( GetBody(), findFile, &file );
 
 			// cerr << endl << "After Split" << endl;
 			// xmlElemDump(stderr, NULL, sequence);
@@ -1499,10 +1613,10 @@ bool PlayList::Delete( int first, int last )
 		firstCall = 0;
 	}
 
-	xmlNodePtr srcNode = xmlDocGetRootElement( doc );
+	xmlNodePtr srcNode = GetBody();
 	absClipBegin = 0;
 	xmlNodePtr nextSequence = NULL;
-	for ( xmlNodePtr srcSeq = srcNode->xmlChildrenNode; srcSeq != NULL; srcSeq = nextSequence )
+	for ( xmlNodePtr srcSeq = srcNode->children; srcSeq != NULL; srcSeq = nextSequence )
 	{
 
 		dirty = true;
@@ -1514,7 +1628,7 @@ bool PlayList::Delete( int first, int last )
 		{
 			xmlNodePtr nextVideo = NULL;
 
-			for ( xmlNodePtr srcVideo = srcSeq->xmlChildrenNode; srcVideo != NULL; srcVideo = nextVideo )
+			for ( xmlNodePtr srcVideo = srcSeq->children; srcVideo != NULL; srcVideo = nextVideo )
 			{
 
 				// In case we have to delete this node
@@ -1603,7 +1717,7 @@ bool PlayList::Delete( int first, int last )
 
 			// if the node is now empty, delete it (can delete - see nextSequence above)
 
-			if ( srcSeq->xmlChildrenNode == NULL )
+			if ( srcSeq->children == NULL )
 			{
 				xmlUnlinkNode( srcSeq );
 				xmlFreeNode( srcSeq );
@@ -1660,8 +1774,7 @@ bool PlayList::LoadMediaObject( char *filename )
 	existingFrames = GetNumFrames();
 
 	seq = xmlNewNode( NULL, ( const xmlChar* ) "seq" );
-	node = xmlDocGetRootElement( doc );
-	xmlAddChild( node, seq );
+	xmlAddChild( GetBody(), seq );
 	node = xmlNewNode( NULL, ( const xmlChar* ) "video" );
 	xmlNewProp( node, ( const xmlChar* ) "src", ( const xmlChar* ) filename );
 	xmlNewProp( node, ( const xmlChar* ) "clipBegin", ( const xmlChar* ) "0" );
@@ -1698,7 +1811,7 @@ bool PlayList::LoadPlayList( char *filename )
 		doc = NULL;
 		return false;
 	}
-	ns = xmlSearchNsByHref( doc, node, ( const xmlChar * ) "http://www.w3.org/2001/SMIL20/Language" );
+	ns = xmlSearchNsByHref( doc, node, SMIL20_NAMESPACE_HREF );
 	if ( ns == NULL )
 	{
 		cerr << "document of the wrong type, Namespace not found" << endl;
@@ -1717,14 +1830,39 @@ bool PlayList::LoadPlayList( char *filename )
 
 	// PASS PATH
 	string path = directory_utils::get_directory_from_file( filename );
-	parse( xmlDocGetRootElement( doc ), fillMap, &path );
+	parse( GetBody(), fillMap, &path );
 	dirty = false;
+
+	// Legacy documents have smil2 namespace prefix declaration
+	if ( xmlSearchNs( doc, node, ( const xmlChar * ) "smil2" ) == NULL )
+	{
+		// New age compliant documents use SMIL time values, but we continue
+		// to use frame numbers internally.
+		parse( node, convertSmilTimeToFrames, NULL );
+	}
+	else
+	{
+		// We need to insert a body element into the legacy document
+		xmlNodePtr body = xmlNewNode( NULL, ( const xmlChar * ) "body" );
+		xmlNodePtr root = xmlDocGetRootElement( doc );
+		xmlNodePtr seq = root->children;
+		while ( seq )
+		{
+			xmlNodePtr next = seq->next;
+			xmlUnlinkNode( seq );
+			xmlAddChild( body, seq );
+			seq = next;
+		}
+		xmlAddChild( root, body );
+		dirty = true;
+	}
+
 	RefreshCount( );
 
 	return true;
 }
 
-static bool relativeMap( xmlNodePtr node, void *p )
+static bool relativeMap( xmlNodePtr node, void *p, bool *freed )
 {
 	if ( xmlStrcmp( node->name, ( const xmlChar* ) "video" ) == 0 )
 	{
@@ -1747,32 +1885,43 @@ static bool relativeMap( xmlNodePtr node, void *p )
 }
 
 
-bool PlayList::SavePlayList( char *filename )
+bool PlayList::SavePlayList( char *filename, bool isLegacyFormat )
 {
 	// Try to save file
 	bool ret = false;
+	// Copy the xml doc
+	xmlDocPtr copy_doc = xmlNewDoc( ( const xmlChar* ) "1.0" );
+	xmlNodePtr root = xmlNewNode( NULL, ( const xmlChar* ) "smil" );
+	xmlNewNs( root, ( const xmlChar* ) SMIL20_NAMESPACE_HREF, ( const xmlChar* ) NULL );
+	xmlDocSetRootElement( copy_doc, root );
+	parse( this->GetBody(), clone, &root );
+
+	if ( isLegacyFormat )
+		// Add legacy namespace declaration
+		xmlNewNs( xmlDocGetRootElement( copy_doc ), SMIL20_NAMESPACE_HREF, ( const xmlChar* ) "smil2" );
+	else
+		// Convert frame numbers used internally to SMIL time values.
+		parse( copy_doc->children, convertFramesToSmilTime, NULL );
 
 	if ( Preferences::getInstance().relativeSave )
 	{
 		// Obtain path relative to filenames directory
 		string path = directory_utils::get_directory_from_file( filename );
-		// Copy the xml doc
-		xmlDocPtr copy_doc = xmlCopyDoc( doc, true );
 		// Convert the copy to relative
-		parse( xmlDocGetRootElement( copy_doc ), relativeMap, &path );
+		parse( copy_doc->children, relativeMap, &path );
 		// Save the copy
 		ret = xmlSaveFormatFile( filename, copy_doc, 1 ) != -1;
-		// Delete the copy
-		xmlFreeDoc( copy_doc );
 	}
 	else
 	{
 		// Can save directly
-		ret = xmlSaveFormatFile( filename, doc, 1 ) != -1;
+		ret = xmlSaveFormatFile( filename, copy_doc, 1 ) != -1;
 	}
+	// Delete the copy
+	xmlFreeDoc( copy_doc );
 
 	// If saved...
-	if ( ret )
+	if ( !isLegacyFormat && ret )
 	{
 		// ... and doc name is unspecified, we have now and we're not dirty any more
 		// though all undos are dirty
@@ -1810,7 +1959,7 @@ bool PlayList::SavePlayListEli( char * filename, bool isPAL )
 	EliInfos eli;
 	if ( doc != NULL )
 	{
-		parse( xmlDocGetRootElement( doc ), convertEli, &eli );
+		parse( GetBody(), convertEli, &eli );
 	}
 
 	/* Open a file */
@@ -1874,14 +2023,18 @@ void PlayList::CleanPlayList( xmlNodePtr node )
 
 		xmlNodePtr nodeToDelete = NULL;
 
-		CleanPlayList( node->xmlChildrenNode );
+		CleanPlayList( node->children );
 		if ( xmlStrcmp( node->name, ( const xmlChar* ) "smil" ) == 0 )
 		{
 			//do nothing
 		}
+		else if ( xmlStrcmp( node->name, ( const xmlChar* ) "body" ) == 0 )
+		{
+			//do nothing
+		}
 		else if ( xmlStrcmp( node->name, ( const xmlChar* ) "seq" ) == 0 )
 		{
-			if ( node->xmlChildrenNode == NULL )
+			if ( node->children == NULL )
 			{
 				nodeToDelete = node;
 			}
@@ -1922,7 +2075,7 @@ void PlayList::CleanPlayList( )
     \result true if file has been found and xml tree walk is done 
 */
 
-static bool checkIfFileUsed( xmlNodePtr node, void *p )
+static bool checkIfFileUsed( xmlNodePtr node, void *p, bool *freed )
 {
 	if ( xmlStrcmp( node->name, ( const xmlChar* ) "video" ) == 0 )
 	{
@@ -1943,7 +2096,7 @@ static bool checkIfFileUsed( xmlNodePtr node, void *p )
 
 bool PlayList::IsFileUsed( string filename ) const
 {
-	return parse( xmlDocGetRootElement( doc ), checkIfFileUsed, &filename );
+	return parse( GetBody(), checkIfFileUsed, &filename );
 }
 
 /** Returns the current setting of the dirty flag
@@ -2032,7 +2185,7 @@ string PlayList::GetSeqAttribute( int frameNum, const char* name ) const
 	data.absEnd = 0;
 	data.absFrame = frameNum;
 
-	if ( parse( xmlDocGetRootElement( doc ), findSceneStart, &data ) && data.sequence )
+	if ( parse( GetBody(), findSceneStart, &data ) && data.sequence )
 	{
 		const char *value = ( const char* ) xmlGetProp( data.sequence, ( const xmlChar * ) name );
 		if ( value )
@@ -2051,7 +2204,7 @@ bool PlayList::SetSeqAttribute( int frameNum, const char* name, const char* valu
 	data.absEnd = 0;
 	data.absFrame = frameNum;
 
-	if ( parse( xmlDocGetRootElement( doc ), findSceneStart, &data ) && data.sequence )
+	if ( parse( GetBody(), findSceneStart, &data ) && data.sequence )
 	{
 		xmlSetProp( data.sequence, ( const xmlChar * ) name, ( const xmlChar * ) value );
 		dirty = true;
@@ -2063,9 +2216,9 @@ bool PlayList::SetSeqAttribute( int frameNum, const char* name, const char* valu
 
 bool PlayList::SetDocId( const char* value )
 {
-	if ( xmlDocGetRootElement( doc ) )
+	if ( GetBody() )
 	{
-		xmlSetProp( xmlDocGetRootElement( doc ), ( const xmlChar * ) "id", ( const xmlChar * ) value );
+		xmlSetProp( GetBody(), ( const xmlChar * ) "id", ( const xmlChar * ) value );
 		dirty = true;
 		return true;
 	}
@@ -2075,9 +2228,9 @@ bool PlayList::SetDocId( const char* value )
 
 string PlayList::GetDocId( ) const
 {
-	if ( xmlDocGetRootElement( doc ) )
+	if ( GetBody() )
 	{
-		const char *value = ( const char* ) xmlGetProp( xmlDocGetRootElement( doc ), ( const xmlChar * ) "id" );
+		const char *value = ( const char* ) xmlGetProp( GetBody(), ( const xmlChar * ) "id" );
 		if ( value )
 			return value;
 	}
@@ -2087,9 +2240,9 @@ string PlayList::GetDocId( ) const
 
 bool PlayList::SetDocTitle( const char* value )
 {
-	if ( xmlDocGetRootElement( doc ) )
+	if ( GetBody() )
 	{
-		xmlSetProp( xmlDocGetRootElement( doc ), ( const xmlChar * ) "title", ( const xmlChar * ) value );
+		xmlSetProp( GetBody(), ( const xmlChar * ) "title", ( const xmlChar * ) value );
 		dirty = true;
 		return true;
 	}
@@ -2099,9 +2252,9 @@ bool PlayList::SetDocTitle( const char* value )
 
 string PlayList::GetDocTitle( ) const
 {
-	if ( xmlDocGetRootElement( doc ) )
+	if ( GetBody() )
 	{
-		const char *value = ( const char* ) xmlGetProp( xmlDocGetRootElement( doc ), ( const xmlChar * ) "title" );
+		const char *value = ( const char* ) xmlGetProp( GetBody(), ( const xmlChar * ) "title" );
 		if ( value )
 			return value;
 	}
