@@ -124,7 +124,7 @@ void Preferences::get( bool& var, const char* name, const char* def )
 */
 Preferences::Preferences() : phyID( -1 )
 {
-	char key[ 256 ];
+	char* key = new char[4096];
 	string filename;
 	
 	// Give the new config file priority, but failover to the old gnome-config one
@@ -143,9 +143,9 @@ Preferences::Preferences() : phyID( -1 )
 	// Put the config entries into member vars with defaults
 	get( file, sizeof(file), "file", "capture" );
 	get( defaultNormalisation, "defaultNormalisation", "0" );
-	get( defaultAudio, "defaultAudio", "0" );
+	get( defaultAudio, "defaultAudio", "2" );
 	get( defaultAspect, "defaultAspect", "0" );
-	snprintf( key, 255, "%d", RAW_FORMAT );
+	snprintf( key, 4096, "%d", RAW_FORMAT );
 	get( fileFormat, "fileFormat", key );
 	get( autoSplit, "autoSplit", "true" );
 	get( timeStamp, "timeStamp", "false" );
@@ -154,7 +154,7 @@ Preferences::Preferences() : phyID( -1 )
 	get( interface, "interface", "0" );
 	get( channel, "channel", "63" );
 	get( avcGUID, sizeof(avcGUID), "avcGUID", "" );
-	snprintf( key, 255, "%d", DISPLAY_XV );
+	snprintf( key, 4096, "%d", DISPLAY_XV );
 	get( displayMode, "displayMode", key );
 	get( displayQuality, "displayQuality", "2" );
 	get( displayFixed, "displayFixed", "false" );
@@ -211,6 +211,9 @@ Preferences::Preferences() : phyID( -1 )
 	get( exportMjpegCleanup, "exportMjpegCleanup", "true" );
 	get( exportMjpegOutputDVDAuthorXML, "exportMjpegOutputDVDAuthorXML", "false" );
 	get( exportMjpegDvdTool, "exportMjpegDvdTool", "0" );
+	get( exportMjpegVideoPipe, sizeof(exportMjpegVideoPipe), "exportMjpegVideoPipe", "mpeg2enc -v 0" );
+	get( exportMjpegAudioPipe, sizeof(exportMjpegAudioPipe), "exportMjpegAudioPipe", "mp2enc -v 0" );
+	get( exportMjpegMultiplex, sizeof(exportMjpegMultiplex), "exportMjpegMultiplex", "mplex -v 0" );
 
 	// build a metaValues key for each metaName
 	// metaValues is a range of values to pick from
@@ -228,15 +231,14 @@ Preferences::Preferences() : phyID( -1 )
 		if ( metaname.at( 0 ) == '*' )
 			metaname.erase( 0, 1 );
 
-		str << "metaValues_" << metaname << "=*";
-		char* tempString = g_key_file_get_string( config, GKEYFILE_GROUP, str.str().c_str(), NULL );
-		if ( tempString )
+		str << "metaValues_" << metaname;
+		get( key, 4096, str.str().c_str(), "*" );
 		{
 			vector< string > metaValuesSimpleList;
 			vector< string >::iterator iter;
 			vector< pair< string, string > > metaValuesList;
 
-			string_utils::split( tempString, ",", metaValuesSimpleList );
+			string_utils::split( key, ",", metaValuesSimpleList );
 			for ( iter = metaValuesSimpleList.begin(); iter != metaValuesSimpleList.end(); ++iter )
 			{
 				vector< string > labelValueVector;
@@ -256,6 +258,7 @@ Preferences::Preferences() : phyID( -1 )
 	JogShuttleInit();
 	
 	Save();
+	delete[] key;
 }
 
 
@@ -734,6 +737,9 @@ Preferences::Save()
 	set( "exportMjpegCleanup", exportMjpegCleanup );
 	set( "exportMjpegOutputDVDAuthorXML", exportMjpegOutputDVDAuthorXML );
 	set( "exportMjpegDvdTool", exportMjpegDvdTool );
+	set( "exportMjpegVideoPipe", exportMjpegVideoPipe );
+	set( "exportMjpegAudioPipe", exportMjpegAudioPipe );
+	set( "exportMjpegMultiplex", exportMjpegMultiplex );
 
 	// Persist
 	string filename = kino_config_file();
