@@ -214,6 +214,11 @@ public:
 	bool exportMjpegCleanup;
 	bool exportMjpegOutputDVDAuthorXML;
 	int exportMjpegDvdTool;
+	char exportMjpegVideoPipe[512];
+	char exportMjpegAudioPipe[512];
+	char exportMjpegMultiplex[512];
+
+	// Other "sticky" options
 	bool enableAVC;
 
 	void Save();
