@@ -309,6 +309,9 @@ extern "C"
 
 		widget = lookup_widget( dialog, "optionmenu_avc_phyid" );
 
+#ifdef HAVE_DV1394
+		gtk_widget_hide_all( lookup_widget( dialog, "hbox_ieee1394_warning" ) );
+#endif
 		if ( ( handle = raw1394_new_handle() ) )
 		{
 			raw1394_portinfo ports[MAX_1394_PORTS];
@@ -461,7 +464,7 @@ extern "C"
 		
 		gtk_widget_set_sensitive( widget, gtk_toggle_button_get_active( togglebutton ) );
 		if ( warn )
-			modal_message_with_parent( _("You must restart Kino for V4L option to take effect."), widget );
+			modal_message_with_parent( widget, _("You must restart Kino for V4L option to take effect.") );
 		warn = true;
 	}
 
