@@ -15,51 +15,6 @@
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
-*
-* Tag: $Name:  $
-*
-* Change log:
-* 
-* $Log: riff.cc,v $
-* Revision 1.17  2004/10/11 01:37:11  ddennedy
-* mutex safety locks in RIFF and AVI classes, type 2 AVI optimization, mencoder export script
-*
-* Revision 1.16  2003/11/25 23:01:24  ddennedy
-* cleanup and a few bugfixes
-*
-* Revision 1.15  2003/10/21 16:34:34  ddennedy
-* GNOME2 port phase 1: initial checkin
-*
-* Revision 1.13.2.3  2003/08/26 20:39:00  ddennedy
-* relocate mutex unlock and add assert includes
-*
-* Revision 1.13.2.2  2003/01/28 12:54:13  lilo_booter
-* New 'no change' image transition
-*
-* Revision 1.13.2.1  2002/11/25 04:48:31  ddennedy
-* bugfix to report errors when loading files
-*
-* Revision 1.13  2002/09/13 06:49:49  ddennedy
-* build update, cleanup, bugfixes
-*
-* Revision 1.12  2002/04/21 06:36:40  ddennedy
-* kindler avc and 1394 bus reset support in catpure page, honor max file size
-*
-* Revision 1.11  2002/04/09 06:53:42  ddennedy
-* cleanup, new libdv 0.9.5, large AVI, dnd storyboard
-*
-* Revision 1.4  2002/03/25 21:34:25  arne
-* Support for large (64 bit) files mostly completed
-*
-* Revision 1.3  2002/03/10 21:28:29  arne
-* release 1.1b1, 64 bit support for type 1 avis
-*
-* Revision 1.2  2002/03/04 19:22:43  arne
-* updated to latest Kino avi code
-*
-* Revision 1.1.1.1  2002/03/03 19:08:08  arne
-* import of version 1.01
-*
 */
 
 #ifdef HAVE_CONFIG_H
@@ -75,6 +30,7 @@
 #include <byteswap.h>
 
 using std::cout;
+using std::cerr;
 using std::hex;
 using std::dec;
 using std::setw;
@@ -108,7 +64,7 @@ FOURCC make_fourcc( char *s )
 	if ( s[ 0 ] == 0 )
 		return 0;
 	else
-		return *( ( unsigned int* ) s );
+		return *( ( FOURCC* ) s );
 }
 
 
@@ -409,22 +365,22 @@ void RIFFFile::PrintDirectoryEntry ( int i ) const
 	   length and file offset. */
 
 	cout << hex << setfill( '0' ) << "type: "
-	<< ( char ) ( ( entry.type >> 0 ) & 0x000000ff )
-	<< ( char ) ( ( entry.type >> 8 ) & 0x000000ff )
-	<< ( char ) ( ( entry.type >> 16 ) & 0x000000ff )
-	<< ( char ) ( ( entry.type >> 24 ) & 0x000000ff )
+	<< ((char *)&entry.type)[0]
+	<< ((char *)&entry.type)[1]
+	<< ((char *)&entry.type)[2]
+	<< ((char *)&entry.type)[3]
 	<< " name: "
-	<< ( char ) ( ( entry_name >> 0 ) & 0x000000ff )
-	<< ( char ) ( ( entry_name >> 8 ) & 0x000000ff )
-	<< ( char ) ( ( entry_name >> 16 ) & 0x000000ff )
-	<< ( char ) ( ( entry_name >> 24 ) & 0x000000ff )
+	<< ((char *)&entry_name)[0]
+	<< ((char *)&entry_name)[1]
+	<< ((char *)&entry_name)[2]
+	<< ((char *)&entry_name)[3]
 	<< " length: 0x" << setw( 12 ) << entry.length
 	<< " offset: 0x" << setw( 12 ) << entry.offset
 	<< " list: "
-	<< ( char ) ( ( list_name >> 0 ) & 0x000000ff )
-	<< ( char ) ( ( list_name >> 8 ) & 0x000000ff )
-	<< ( char ) ( ( list_name >> 16 ) & 0x000000ff )
-	<< ( char ) ( ( list_name >> 24 ) & 0x000000ff ) << dec << endl;
+	<< ((char *)&list_name)[0]
+	<< ((char *)&list_name)[1]
+	<< ((char *)&list_name)[2]
+	<< ((char *)&list_name)[3] << dec << endl;
 
 	/* print the content itself */
 
@@ -498,7 +454,7 @@ int RIFFFile::FindDirectoryEntry ( FOURCC type, int n ) const
 void RIFFFile::ParseChunk( int parent )
 {
 	FOURCC type;
-	int length;
+	DWORD length;
 	int typesize;
 
 	/* Check whether it is a LIST. If so, let ParseList deal with it */
@@ -535,7 +491,7 @@ void RIFFFile::ParseList( int parent )
 	FOURCC type;
 	FOURCC name;
 	int list;
-	int length;
+	DWORD length;
 	off_t pos;
 	off_t	listEnd;
 
@@ -577,7 +533,7 @@ void RIFFFile::ParseList( int parent )
 void RIFFFile::ParseRIFF( void )
 {
 	FOURCC type;
-	int length;
+	DWORD length;
 	off_t filesize;
 	off_t pos;
 	int container = AddDirectoryEntry( make_fourcc( "FILE" ), make_fourcc( "FILE" ), 0, RIFF_NO_PARENT );
@@ -608,15 +564,37 @@ void RIFFFile::ParseRIFF( void )
  
 */
 
-void RIFFFile::ReadChunk( int chunk_index, void *data )
+bool RIFFFile::ReadChunk( int chunk_index, void *data, off_t data_len )
 {
 	RIFFDirEntry entry;
 
 	entry = GetDirectoryEntry( chunk_index );
+#ifdef DEBUG
+	if ( entry.length > data_len ) {
+		FOURCC entry_name = entry.name ? entry.name : make_fourcc( "    " );
+
+		cerr << dec << "Warning: insufficient storage in RIFFFile::ReadChunk(): data_len " << data_len << " entry.length " << entry.length << endl;
+		cerr << hex << setfill( '0' ) << "         type: "
+		<< ((char *)&entry.type)[0]
+		<< ((char *)&entry.type)[1]
+		<< ((char *)&entry.type)[2]
+		<< ((char *)&entry.type)[3]
+		<< " name: "
+		<< ((char *)&entry_name)[0]
+		<< ((char *)&entry_name)[1]
+		<< ((char *)&entry_name)[2]
+		<< ((char *)&entry_name)[3]
+		<< " length: 0x" << setw( 12 ) << entry.length
+		<< " offset: 0x" << setw( 12 ) << entry.offset
+		<< endl;
+	}
+#endif
 	pthread_mutex_lock( &file_mutex );
 	fail_if( lseek( fd, entry.offset, SEEK_SET ) == ( off_t ) - 1 );
-	fail_neg( read( fd, data, entry.length ) );
+	fail_neg( read( fd, data, entry.length > data_len ? data_len : entry.length ) );
 	pthread_mutex_unlock( &file_mutex );
+
+	return ( entry.length <= data_len );
 }
 
 
@@ -635,7 +613,7 @@ void RIFFFile::WriteChunk( int chunk_index, const void *data )
 	pthread_mutex_lock( &file_mutex );
 	fail_if( lseek( fd, entry.offset - RIFF_HEADERSIZE, SEEK_SET ) == ( off_t ) - 1 );
 	fail_neg( write( fd, &entry.type, sizeof( entry.type ) ) );
-	int length = entry.length;
+	DWORD length = entry.length;
 	fail_neg( write( fd, &length, sizeof( length ) ) );
 	fail_neg( write( fd, data, entry.length ) );
 	pthread_mutex_unlock( &file_mutex );
@@ -682,7 +660,7 @@ void RIFFFile::WriteRIFF( void )
 
 			fail_if( lseek( fd, entry.offset - RIFF_HEADERSIZE, SEEK_SET ) == ( off_t ) - 1 ) ;
 			fail_neg( write( fd, &entry.type, sizeof( entry.type ) ) );
-			int length = entry.length;
+			DWORD length = entry.length;
 			fail_neg( write( fd, &length, sizeof( length ) ) );
 
 			/* If it has a name, it is a list. Write out the extra name
