@@ -15,42 +15,6 @@
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
-*
-* Tag: $Name:  $
-*
-* Change log:
-* 
-* $Log: riff.h,v $
-* Revision 1.13  2004/10/11 01:37:11  ddennedy
-* mutex safety locks in RIFF and AVI classes, type 2 AVI optimization, mencoder export script
-*
-* Revision 1.12  2004/01/06 22:53:42  ddennedy
-* metadata editing tweaks and bugfixes, new ui elements in preparation for publish functions
-*
-* Revision 1.11  2003/11/25 23:01:25  ddennedy
-* cleanup and a few bugfixes
-*
-* Revision 1.10  2003/10/21 16:34:34  ddennedy
-* GNOME2 port phase 1: initial checkin
-*
-* Revision 1.8.4.1  2002/11/25 04:48:31  ddennedy
-* bugfix to report errors when loading files
-*
-* Revision 1.8  2002/04/21 06:36:40  ddennedy
-* kindler avc and 1394 bus reset support in catpure page, honor max file size
-*
-* Revision 1.7  2002/04/09 06:53:42  ddennedy
-* cleanup, new libdv 0.9.5, large AVI, dnd storyboard
-*
-* Revision 1.3  2002/03/25 21:34:25  arne
-* Support for large (64 bit) files mostly completed
-*
-* Revision 1.2  2002/03/04 19:22:43  arne
-* updated to latest Kino avi code
-*
-* Revision 1.1.1.1  2002/03/03 19:08:08  arne
-* import of version 1.01
-*
 */
 
 #ifndef _RIFF_H
@@ -61,12 +25,14 @@ using std::vector;
 
 #include <pthread.h>
 
-#define QUADWORD signed long long
-#define DWORD signed int
-#define LONG unsigned int
-#define WORD signed short
-#define BYTE unsigned char
-#define FOURCC unsigned int
+#include "endian_types.h"
+
+#define QUADWORD int64_le_t
+#define DWORD int32_le_t
+#define LONG u_int32_le_t
+#define WORD int16_le_t
+#define BYTE u_int8_le_t
+#define FOURCC u_int32_t      // No endian conversion needed.
 
 #define RIFF_NO_PARENT (-1)
 #define RIFF_LISTSIZE (4)
@@ -118,7 +84,7 @@ public:
 	virtual void ParseChunk( int parent );
 	virtual void ParseList( int parent );
 	virtual void ParseRIFF( void );
-	virtual void ReadChunk( int chunk_index, void *data );
+	virtual bool ReadChunk( int chunk_index, void *data, off_t data_len );
 	virtual void WriteChunk( int chunk_index, const void *data );
 	virtual void WriteRIFF( void );
 
