@@ -40,9 +40,10 @@ extern "C"
 #include "cell-renderers/mg-popup-entry.h"
 #include "cell-renderers/mg-cell-renderer-popup.h"
 #include "cell-renderers/mg-cell-renderer-list.h"
+
+	extern KinoCommon *common;
+	extern struct navigate_control g_nav_ctl;
 }
-extern KinoCommon *common;
-extern struct navigate_control g_nav_ctl;
 
 enum SceneStatus {
     SCENE_INIT,
@@ -354,7 +355,7 @@ on_value_edited( MgCellRendererList *cell,
 			// See if values range is open-ended (* in metaValues)
 			for ( metaValuesIter = metaValues.begin(); metaValuesIter != metaValues.end() && metaValuesIter->first != "*"; ++metaValuesIter );
 
-			if ( MG_CELL_RENDERER_POPUP( cell )->shown == FALSE )
+			if ( metaValuesIter != metaValues.end() && MG_CELL_RENDERER_POPUP( cell )->shown == FALSE )
 			{
 				// Get the value from the entry
 				label = value = const_cast< char* >( mg_popup_entry_get_text( MG_POPUP_ENTRY( cell->parent.editable ) ) );
