@@ -640,9 +640,9 @@ void *V4L::getNextFrame()
 	frame_next = ( frame_next + 1 ) % frame_maps;
 	
 	if ( ioctl( fd, VIDIOCMCAPTURE, &frame[ frame_next ] ) == -1 )
-		cout << "Frame 1 Failed to initialise" << endl;
+		; //cout << "Frame 1 Failed to initialise" << endl;
 	if ( ioctl( fd, VIDIOCSYNC, &frame[ current ].frame ) == -1 )
-		cout << "Frame 0 Failed to sync" << endl;
+		; //cout << "Frame 0 Failed to sync" << endl;
 	ret = ( unsigned char * ) map + current * ( mappedMemorySize( ) / frame_maps );
 	
 	frames ++;
